@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -479,64 +479,15 @@ logical do_aliasn(char *name, unsigned char convfloor, logical multibyte) {
 }
 
 logical do_aliasb(char *name) {
-  /* NB aliasB is at parse time, aliasb for compiling Browser Summary. */
-  /* See Bnextname() for the role of this function. */
-  char *s, *t;
-  logical done = FALSE;
-
-  if (headmatch(name, "Mozilla")) {
-    if (*(name + 7) == '/' && *(name + 8) == '5') {
-      /* Mozilla/5 is messy. The real version number should be written at the
-	 end of the brackets. Furthermore, there are (so far) three different
-	 version number formats, "m18", "0.8" and "rv:0.9.1+".
-	 
-	 We've filtered out Mozilla/5.0 (compatible) in Bnextname() so these
-	 should all be genuine Mozilla. But if we can't find a version number
-	 we'll just leave it as Mozilla, not Mozilla/5.0, to avoid confusing
-	 the two different numbering schemes. */
-      if ((t = strstr(name, ") Gecko")) != NULL) {
-	/* There should only be one ')', but let's be cautious. */
-	for (s = t - 1; *s != ' ' && s != name; s--)
-	  ;  /* run back to space before last element inside brackets */
-	if (s != name && *(s - 1) == ';') {
-	  s++;
-	  if (headmatch(s, "rv:"))
-	    s += 3;
-	  if (ISDIGIT(*s) || (*s == 'm' && ISDIGIT(*(s + 1)))) { /* Found it */
-	    if (*s == 'm')
-	      *s = 'M';
-	    memcpy(name + 8, s, t - s);
-	    *(name + 8 + (t - s)) = '\0';
-	    done = TRUE;
-	  }
-	}
-      }
-      if (!done)
-	*(name + 7) = '\0';
-      return(TRUE);
-    }
-
-    /* All other Mozilla's are reckoned to be Netscape */
-    memmove(name + 8, name + 7, strlen(name + 7) + 1);
-    strncpy(name, "Netscape", 8);
+  /* NB aliasB is at parse time, aliasb for compiling browsum */
+  /* not much left to do here coz most of the intelligence is in Bnextname() */
+  if (headmatch(name, "WebTV ") || headmatch(name, "Opera ")) {
+    if (ISDIGIT(*(name + 6)))
+      *(name + 5) = '/';
   }
+  else if (headmatch(name, "MSIE ") && ISDIGIT(*(name + 5)))
+    *(name + 4) = '/';
 
-  /* Convert "Galeon; n.m" to "Galeon/n.m"; n a digit tested in Bnextname() */
-  else if (headmatch(name, "Galeon; ")) {
-    *(name + 6) = '/';
-    memmove(name + 7, name + 8, strlen(name + 8) + 1);
-    return(TRUE);
-  }
-
-  /* Netscape6 is actually Netscape */
-  else if (headmatch(name, "Netscape6"))
-    memmove(name + 8, name + 9, strlen(name + 9) + 1);
-
-  /* In general, convert "Name n.m" to "Name/n.m" if n a digit */
-  for (s = name; ISALNUM(*s); s++)
-    ;
-  if (*s == ' ' && ISDIGIT(*(s + 1)))
-    *s = '/';
   return(TRUE);
 }
 
@@ -580,7 +531,7 @@ logical dnsresolve(char *name, choice level) {
       signal(SIGALRM, sighandler);
       alarm(dnstimeout);
 #endif
-      tempp = gethostbyaddr(addrp, sizeof(IN_ADDR_T), AF_INET);
+      tempp = gethostbyaddr(addrp, sizeof(struct in_addr), AF_INET);
 #ifndef NOALARM
       alarm(0);
       signal(SIGALRM, SIG_DFL);
@@ -685,15 +636,14 @@ void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]) {
   /* Matching has already been checked. name must have length >= BLOCKSIZE. */
   char *s, *ans;
   ptrdiff_t *pm;
-  size_t len, tolen;
+  size_t len;
 
   len = strlen(name);
   ans = name + len;
   /* The aliased name is built AFTER the orig name. */
   for (s = ans; to != NULL; TO_NEXT(to)) {
     pm = &(pmatch[to->after]);
-    tolen = strlen(to->string);
-    len += tolen;
+    len += strlen(to->string);
     if (to->after >= 0 && pm[0] >= 0)
       len += (size_t)(pm[1] - pm[0]);
     if (len >= BLOCKSIZE - 1) {
@@ -701,7 +651,7 @@ void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]) {
       return;
     }
     strcpy(s, to->string);
-    s += tolen;
+    s = strchr(s, '\0');
     if (to->after >= 0 && pm[0] >= 0) {
       memcpy((void *)s, (void *)(name + pm[0]), (size_t)(pm[1] - pm[0]));
       s += pm[1] - pm[0];
@@ -823,9 +773,8 @@ void reverseonename(Hashindex *p) {
   size_t l, m = 0;
   logical done;
 
-  /* reversing done in own space, so pull off const char * cases first */
-  if (STREQ(p->name, LNGSTR_NODOMAIN) || STREQ(p->name, LNGSTR_UNKDOMAIN))
-    return;
+  if (*(p->name) == '\f' || *(p->name) == '\b' || *(p->name) == '\v')
+    return;   /* special codes in Znextname() */
   l = strlen(p->name);                             /* numerical host */
   if (ISDIGIT(*(p->name + l - 1))  && ISDIGIT(*(p->name))) {
     t1 = p->name;
