@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -14,7 +14,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.1"    /* the version number of this program */
+#define VNUMBER "5.02"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -92,32 +92,20 @@
 #define VERSION VNUMBER"/OpenVMS"
 #endif
 
-#ifdef BEOS
-#define NOALARM
-#define NOFOLLOW
-#define PATHSEPS "/"
-#define DIRSEP '/'
-#define EXTSEP '.'
-#define VERSION VNUMBER"/BeOS"
-#endif
-
 #ifdef OSX
 #define PATHSEPS "/"
 #define DIRSEP '/'
 #define EXTSEP '.'
 #define VERSION VNUMBER"/OS X"
-#endif
+#else
 
 #ifdef UNIX
-#ifndef OSX
-#ifndef BEOS
 #define PATHSEPS "/"
 #define DIRSEP '/'
 #define EXTSEP '.'
 #define VERSION VNUMBER"/Unix"
 #endif
 #endif
-#endif
 
 #ifdef WIN32
 #define popen _popen
@@ -171,6 +159,15 @@ extern void Win32Cleanup(void);
 #define VERSION VNUMBER"/NeXTSTEP"
 #endif
 
+#ifdef BEOS
+#define NOALARM
+#define NOFOLLOW
+#define PATHSEPS "/"
+#define DIRSEP '/'
+#define EXTSEP '.'
+#define VERSION VNUMBER"/BeOS"
+#endif
+
 #ifdef MPEIX
 #define NOFOLLOW
 #define PATHSEPS "/"
@@ -348,8 +345,8 @@ extern void mac_free(void *ptr);
 #include <OpenTptInternet.h>
 #include <AddressXlation.h>
 #endif
-#else                        /* Win32 and normal DNS */
-#ifdef HAVE_ADDR_T   /* define in Makefile if in_addr_t != unsigned long */
+#else
+#ifdef HAVE_ADDR_T           /* Win32 and normal DNS */
 #define IN_ADDR_T in_addr_t
 #else
 typedef unsigned long IN_ADDR_T;
@@ -455,26 +452,6 @@ typedef unsigned long IN_ADDR_T;
 #define MAC_IDLE_FREQ (200)
 #endif
 
-/* Special codes for certain reports. We collect them here just to avoid
-   changing several instances if they change (although see Pnenxtname() too).
-   *
-   It would be nice to let the user use localised versions of these in e.g.
-   *EXCLUDE commands, but that doesn't scale to the case of reports in two
-   languages in one pass, because not all trees are built as late as output
-   time. */
-#define LNGSTR_UNRESOLVED "[unresolved numerical addresses]"
-#define LNGSTR_NODOMAIN "[domain not given]"
-#define LNGSTR_UNKDOMAIN "[unknown domain]"
-#define LNGSTR_ROOTDIR "[root directory]"
-#define LNGSTR_NODIR "[no directory]"
-#define LNGSTR_NOEXT "[no extension]"
-#define LNGSTR_BRKDIRS "[directories]"
-#define LNGSTR_UNKWIN "Unknown Windows"
-#define LNGSTR_UNKMAC "Unknown Macintosh"
-#define LNGSTR_UNKUX "Other Unix"
-#define LNGSTR_ROBOTS "Robots"
-#define LNGSTR_UNKOS "OS unknown"
-
 /*** logfile line types ***/
 
 #define LOG_COMMON1 "%S %j %u [%d/%M/%Y:%h:%n:%j] \"%j%w%r%wHTTP%j\" %c %b"
@@ -487,10 +464,14 @@ typedef unsigned long IN_ADDR_T;
   "%S %j %u [%d/%M/%Y:%h:%n:%j] \"%j%w%r\" %c %b \"%f\" \"%B\""
 #define LOG_COMBINED3 \
   "%S %j %u [%d/%M/%Y:%h:%n:%j] \"%r\" %c %b \"%f\" \"%B\""
-#define LOG_MS_INT1 "%S, %u, %d/%m/%Z, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
-#define LOG_MS_INT2 "%*S, %*u, %d/%m/%Z, %h:%n:%j, %j"
-#define LOG_MS_NA1 "%S, %u, %m/%d/%Z, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
-#define LOG_MS_NA2 "%*S, %*u, %m/%d/%Z, %h:%n:%j, %j"
+#define LOG_MS_INT2A "%S, %u, %d/%m/%y, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
+#define LOG_MS_INT2B "%*S, %*u, %d/%m/%y, %h:%n:%j, %j"
+#define LOG_MS_INT4A "%S, %u, %d/%m/%Y, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
+#define LOG_MS_INT4B "%*S, %*u, %d/%m/%Y, %h:%n:%j, %j"
+#define LOG_MS_NA2A "%S, %u, %m/%d/%y, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
+#define LOG_MS_NA2B "%*S, %*u, %m/%d/%y, %h:%n:%j, %j"
+#define LOG_MS_NA4A "%S, %u, %m/%d/%Y, %h:%n:%j, W3SVC%j, %j, %v, %T, %j, %b, %c, %j, %j, %r, %q,"
+#define LOG_MS_NA4B "%*S, %*u, %m/%d/%Y, %h:%n:%j, %j"
 #define LOG_WEBSTAR1 "!!LOG_FORMAT%x2"
 #define LOG_WEBSTAR2 "!!%j"
 #define LOG_EXTENDED1 "#Fields:%x3"
@@ -519,22 +500,20 @@ enum {ITEM_VHOST, ITEM_FILE, ITEM_USER, ITEM_REFERRER, ITEM_BROWSER, ITEM_HOST,
 #define ITEM_NUMBER (INP_CODE)
 #define INPUT_NUMBER (INP_YEAR)  /* NB There is INP_NUMBER and INPUT_NUMBER */
 
-/* Types of report. They must be in the following order: date Reports;
-   date Summaries; GENSUM; general reports; dervreps; arrayreps.
-   (The order is insignificant within each section.) */
+/* Types of report: must have date reports then GENSUM then other reports,
+   finishing with dervreps, then SIZE, CODE, PROCTIME in some order. */
 /* See also repcodes, anchorname and repname in globals.c */
 /* Also report descriptions files have these entries in this order */
-enum {REP_YEAR, REP_QUARTERLY, REP_MONTH, REP_WEEK, REP_DAYREP, REP_HOURREP,
-      REP_QUARTERREP, REP_FIVEREP, REP_DAYSUM, REP_HOURSUM, REP_WEEKHOUR,
-      REP_QUARTERSUM, REP_FIVESUM, REP_GENSUM, REP_REQ, REP_REDIR, REP_FAIL,
+enum {REP_YEAR, REP_QUARTERLY, REP_MONTH, REP_WEEK, REP_DAYREP, REP_DAYSUM,
+      REP_HOURREP, REP_HOURSUM, REP_WEEKHOUR, REP_QUARTERREP, REP_QUARTERSUM,
+      REP_FIVEREP, REP_FIVESUM, REP_GENSUM, REP_REQ, REP_REDIR, REP_FAIL,
       REP_TYPE, REP_DIR, REP_HOST, REP_REDIRHOST, REP_FAILHOST, REP_DOM,
       REP_REF, REP_REFSITE, REP_REDIRREF, REP_FAILREF, REP_BROWREP, REP_VHOST,
       REP_REDIRVHOST, REP_FAILVHOST, REP_USER, REP_REDIRUSER, REP_FAILUSER,
       REP_ORG, REP_SEARCHREP, REP_SEARCHSUM, REP_INTSEARCHREP,
       REP_INTSEARCHSUM, REP_BROWSUM, REP_OS, REP_SIZE, REP_CODE, REP_PROCTIME,
       REP_NUMBER};
-#define DATEREPORTS_NUMBER (REP_DAYSUM)   /* just the eight "Reports" */
-#define DATEREP_NUMBER (REP_GENSUM)   /* including the five "Summaries" too */
+#define DATEREP_NUMBER (REP_GENSUM)
 #define FIRST_GENREP (REP_GENSUM + 1)
 #define GENREP_NUMBER (REP_NUMBER - FIRST_GENREP)
 #define FIRST_DERVREP (REP_SEARCHREP)
@@ -588,13 +567,12 @@ enum {SUNDAY, MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY};
 /* languages; see also country in globals.c */
 enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
       /*SIMP_CHINESE,*/ TRAD_CHINESE, /*CROATIAN,*/ CZECH, CZECH_1250, DANISH,
-      DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN, /*GREEK,*/
+      DUTCH, ENGLISH, US_ENGLISH, /*FINNISH,*/ FRENCH, GERMAN, /*GREEK,*/
       HUNGARIAN, /*ICELANDIC,*/ ITALIAN, JAPANESE_EUC, JAPANESE_JIS,
       JAPANESE_SJIS, JAPANESE_UTF, KOREAN, LATVIAN, /*LITHUANIAN,*/
       NORWEGIAN, NYNORSK, POLISH, PORTUGUESE, BR_PORTUGUESE,
       /*ROMANIAN, RUSSIAN,*/ SERBIAN, /*SLOVAK,*/ SLOVENE, SLOVENE_1250,
-      SPANISH, SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
-#define OLDLANG (-2)
+      /*SPANISH,*/ SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
 
 /* lngstrs; charset_ must be first */
 enum {charset_, weekbeg_, year_, quarteryr_, month_, day_, days_, hr_, minute_,
@@ -730,11 +708,6 @@ typedef struct {
   void *opt;
 } Configfns;
 
-typedef struct {
-  char *name;
-  choice arg;
-} Choices;
-
 typedef struct {
   char code;
   choice type;
@@ -859,14 +832,14 @@ typedef struct {
   char *outfile, *cacheoutfile;
   char *domainsfile, *descfile, *headerfile, *footerfile;
   choice outstyle, gotos;
-  logical descriptions, multibyte, html, repspan, pdflatex;
+  logical descriptions, multibyte, html, repspan;
   unsigned int rsthresh;
   choice reporder[REP_NUMBER + 1];
   logical repq[REP_NUMBER], last7, runtime;
   choice cols[REP_NUMBER][COL_NUMBER];
-  unsigned int rows[DATEREPORTS_NUMBER];
+  unsigned int rows[DATEREP_NUMBER];
   char graph[DATEREP_NUMBER];
-  logical back[DATEREPORTS_NUMBER];
+  logical back[DATEREP_NUMBER];
   choice chartby[GENREP_NUMBER];
   logical jpegcharts, pngimages;
   choice sortby[GENREP_NUMBER], subsortby[GENREP_NUMBER];
@@ -999,8 +972,8 @@ typedef struct {
 #define ENTRY_BLANK(e) ((e) == blank_entry)
 #define LEN3(n, c) ((unsigned int)((c == '\0')?(n):((n) + (((n) - 1) / 3))))
 /* The length of an n digit number with seps; e.g. 56789 [5] -> 56,789 [6] */
-#define COPYSTR(s, n) {char *z = n; s = (char *)xmalloc(strlen(z) + 1); \
-                       strcpy(s, z);}  /* z needed so n only evaluated once */
+#define DEFAULTSTR(s, n) {s = NULL; \
+                          configstr((void *)(&(s)), NULL, n, NULL, -1);}
 #define TOO_FULL(n, z) ((n) > (z))   /* defn for hash table too full */
 #define TOO_FULL_TREE TOO_FULL
 #define NEW_SIZE(z) (2 * (z))        /* new size of the hash table */
