@@ -1,4 +1,4 @@
-/***             analog 5.01             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -310,7 +310,9 @@ extern void gotos(FILE *outf, Outchoices *od, choice rep);
 extern void report_title(FILE *outf, Outchoices *od, choice rep);
 extern void reportspan(FILE *outf, Outchoices *od, choice rep, timecode_t maxd,
   timecode_t mind, Dateman *dman); 
-extern size_t htmlstrlen(char *s, choice outstyle);
+extern size_t htmlstrlen_normal(char *s, choice outstyle);
+extern size_t htmlstrlen_utf8(char *s, choice outstyle);
+extern size_t htmlstrlen_jis(char *s, choice outstyle);
 extern void matchlength(FILE *outf, choice outstyle, char *s, char c);
 extern void myputc(FILE *outf, char c, choice outstyle);
 extern void htmlfprintf(FILE *outf, Outchoices *od, logical multibyte,
@@ -319,12 +321,11 @@ extern void latexfprintf(FILE *outf, char *s);
 extern void escfprintf(FILE *outf, char *name);
 extern void hrule(FILE *outf, Outchoices *od);
 extern void include_file(FILE *outf, Outchoices *od, char *name, char type);
-extern size_t datefmtlen(Outchoices *od, char *fmt, logical plain,
-  choice allowmonth);
-extern char *datesprintf(Outchoices *od, char *ans, char *fmt, datecode_t date,
+extern size_t datefmtlen(Outchoices *od, char *fmt);
+extern char *datesprintf(Outchoices *od, char *fmt, datecode_t date,
   unsigned int hr, unsigned int min, datecode_t newdate, unsigned int newhr,
   unsigned int newmin, logical running, choice allowmonth); 
-extern char *timesprintf(Outchoices *od, char *ans, char *fmt, timecode_t t,
+extern char *timesprintf(Outchoices *od, char *fmt, timecode_t t,
   choice allowmonth);
 extern int f3printf(FILE *outf, choice outstyle, double x, unsigned int width,
   char sepchar);
