@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -105,20 +105,20 @@ char *methodname[] = {"requests","7-day requests", "pages", "7-day pages", "",
 		      "bytes", "7-day bytes", "alphabetical", "random"};
 /* Filenames for each language, in order of enum in anlghea3.h */
 char *country[] = {"am", /*"ba",*/ "bg", "bgm", "cat", /*"cn",*/ "tw",
-		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", "fi",
+		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", /*"fi",*/
 		   "fr", "de", /*"gr",*/ "hu", /*"is",*/ "it", "jpe", "jpj",
 		   "jps", "jpu", "kr", "lv", /*"lt",*/ "no", "no2", "pl", "pt",
-		   "br", /*"ro", "ru",*/ "yu", /*"sk",*/ "si", "si1", "es",
+		   "br", /*"ro", "ru",*/ "yu", /*"sk",*/ "si", "si1", /*"es",*/
 		   "se", "se2", "tr", "ua"};
 /* Report code letters in order of enum in anlghea3.h */
 /* Any new ones must also be added to reportorder in anlghea2.h */
-char repcodes[] = "1QmWDH45dhw67xrEItiSlLofskKBvRMujJZNnYybpzcP";
+char repcodes[] = "1QmWDdHhw4657xrEItiSlLofskKBvRMujJZNnYybpzcP";
 /* Names for the anchors within the report, in the same order */
 /* At most eight letters, because we use them as filenames too. (This limit is
    assumed in piechart()). */
-char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "hourrep",
-		      "quartrep", "fiverep",  "daysum", "hoursum", "weekhour",
-		      "quartsum", "fivesum", "gensum", "req", "redir", "fail",
+char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "daysum",
+		      "hourrep", "hoursum", "weekhour", "quartrep", "quartsum",
+		      "five", "fivesum", "gensum", "req", "redir", "fail",
 		      "type", "dir", "host", "redihost", "failhost", "dom",
 		      "ref", "refsite", "redirref", "failref", "browrep",
 		      "vhost", "redirvh", "failvh", "user", "rediuser",
@@ -127,10 +127,10 @@ char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "hourrep",
 /* These report names are in English, so not the same as in langfile */
 /* Again in order of enum in anlghea3.h */
 char *repname[] = {"Yearly Report", "Quarterly Report", "Monthly Report",
-		   "Weekly Report", "Daily Report", "Hourly Report",
-		   "Quarter-Hour Report", "Five-Minute Report",
-		   "Daily Summary", "Hourly Summary",
-		   "Hour of the Week Summary", "Quarter-Hour Summary",
+		   "Weekly Report", "Daily Report", "Daily Summary",
+		   "Hourly Report", "Hourly Summary",
+		   "Hour of the Week Summary", "Quarter-Hour Report",
+		   "Quarter-Hour Summary", "Five-Minute Report",
 		   "Five-Minute Summary", "General Summary", "Request Report",
 		   "Redirection Report", "Failure Report", "File Type Report",
 		   "Directory Report", "Host Report",
@@ -356,9 +356,8 @@ Inputfns inpfns[] = { /* first the ITEM fns in any order */
   {'d', INP_DATE, &parseuint2, (void *)&date},
   {'m', INP_MONTH, &parsenmonth, (void *)&month},
   {'M', INP_MONTH, &parsemonth, (void *)&month},
-  {'y', INP_YEAR, &parseyear2, (void *)&year},
+  {'y', INP_YEAR, &parseyear, (void *)&year},
   {'Y', INP_YEAR, &parseuint4strict, (void *)&year},
-  {'Z', INP_YEAR, &parseyear2or4, (void *)&year},
   {'U', INP_UNIXTIME, &parseulong, (void *)&unixtime},
   {'T', INP_PROCTIME, &parseulong, (void *)&proctime},
   {'t', INP_PROCTIME, &parseproctime, (void *)&proctime},
@@ -460,61 +459,61 @@ Configfns cf[] = {
   {"ALLGRAPH", &configallgraph, (void *)(opts.outopts.graph)},
   {"ALLGRAPHS", &configallgraph, (void *)(opts.outopts.graph)},
 #ifndef NOGRAPHICS
-  {"REQCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_REQ)])},
-  {"REDIRCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_REDIR)])},
-  {"FAILCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_FAIL)])},
-  {"TYPECHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_TYPE)])},
-  {"SIZECHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_SIZE)])},
-  {"PROCTIMECHART", &configchoice,
+  {"REQCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_REQ)])},
+  {"REDIRCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_REDIR)])},
+  {"FAILCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_FAIL)])},
+  {"TYPECHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_TYPE)])},
+  {"SIZECHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_SIZE)])},
+  {"PROCTIMECHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_PROCTIME)])},
-  {"DIRCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_DIR)])},
-  {"HOSTCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_HOST)])},
-  {"REDIRHOSTCHART", &configchoice,
+  {"DIRCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_DIR)])},
+  {"HOSTCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_HOST)])},
+  {"REDIRHOSTCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_REDIRHOST)])},
-  {"FAILHOSTCHART", &configchoice,
+  {"FAILHOSTCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_FAILHOST)])},
-  {"DOMCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_DOM)])},
-  {"ORGCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_ORG)])},
-  {"REFCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_REF)])},
-  {"REFSITECHART", &configchoice,
+  {"DOMCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_DOM)])},
+  {"ORGCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_ORG)])},
+  {"REFCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_REF)])},
+  {"REFSITECHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_REFSITE)])},
-  {"REDIRREFCHART", &configchoice,
+  {"REDIRREFCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_REDIRREF)])},
-  {"FAILREFCHART", &configchoice,
+  {"FAILREFCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_FAILREF)])},
-  {"BROWREPCHART", &configchoice,
+  {"BROWREPCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_BROWREP)])},
-  {"BROWSUMCHART", &configchoice,
+  {"BROWSUMCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_BROWSUM)])},
-  {"OSCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_OS)])},
-  {"VHOSTCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_VHOST)])},
-  {"REDIRVHOSTCHART", &configchoice,
+  {"OSCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_OS)])},
+  {"VHOSTCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_VHOST)])},
+  {"REDIRVHOSTCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_REDIRVHOST)])},
-  {"FAILVHOSTCHART", &configchoice,
+  {"FAILVHOSTCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_FAILVHOST)])},
-  {"USERCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_USER)])},
-  {"REDIRUSERCHART", &configchoice,
+  {"USERCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_USER)])},
+  {"REDIRUSERCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_REDIRUSER)])},
-  {"FAILUSERCHART", &configchoice,
+  {"FAILUSERCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_FAILUSER)])},
-  {"SEARCHQUERYCHART", &configchoice,
+  {"SEARCHQUERYCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_SEARCHREP)])},
-  {"SEARCHWORDCHART", &configchoice,
+  {"SEARCHWORDCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_SEARCHSUM)])},
-  {"INTSEARCHQUERYCHART", &configchoice,
+  {"INTSEARCHQUERYCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_INTSEARCHREP)])},
-  {"INTSEARCHWORDCHART", &configchoice,
+  {"INTSEARCHWORDCHART", &configchart,
    (void *)&(opts.outopts.chartby[G(REP_INTSEARCHSUM)])},
-  {"STATUSCHART", &configchoice, (void *)&(opts.outopts.chartby[G(REP_CODE)])},
+  {"STATUSCHART", &configchart, (void *)&(opts.outopts.chartby[G(REP_CODE)])},
   {"ALLCHART", &configallchart, (void *)(opts.outopts.chartby)},
   {"ALLCHARTS", &configallchart, (void *)(opts.outopts.chartby)},
   {"CHARTDIR", &configstr, (void *)&(opts.outopts.chartdir)},
   {"LOCALCHARTDIR", &configstr, (void *)&(opts.outopts.localchartdir)},
 #ifdef HAVE_GD
-  {"JPEGCHARTS", &configchoice, (void *)&(opts.outopts.jpegcharts)},
+  {"JPEGCHARTS", &configonoff, (void *)&(opts.outopts.jpegcharts)},
 #endif
 #endif  /* NOGRAPHICS */
-  {"PNGIMAGES", &configchoice, (void *)&(opts.outopts.pngimages)},
+  {"PNGIMAGES", &configonoff, (void *)&(opts.outopts.pngimages)},
   {"BARSTYLE", &configbarstyle, (void *)&(opts.outopts.barstyle)},
   {"COMPSEP", &configstr, (void *)&(opts.outopts.compsep)},
   {"PRESEP", &configstr, (void *)&(opts.outopts.compsep)},
@@ -742,7 +741,7 @@ Configfns cf[] = {
   {"VHOSTEXCLUDE", &configexc, (void *)&(opts.wanthead[ITEM_VHOST])},
   {"STATUSINCLUDE", &configscinc, (void *)(opts.code2type)},
   {"STATUSEXCLUDE", &configscexc, (void *)(opts.code2type)},
-  {"304ISSUCCESS", &configchoice, (void *)&(opts.succ304)},
+  {"304ISSUCCESS", &configonoff, (void *)&(opts.succ304)},
   {"REQINCLUDE", &configinc, (void *)&(opts.outopts.wanthead[G(REP_REQ)])},
   {"REQEXCLUDE", &configexc, (void *)&(opts.outopts.wanthead[G(REP_REQ)])},
   {"REDIRINCLUDE", &configinc, (void *)&(opts.outopts.wanthead[G(REP_REDIR)])},
@@ -863,171 +862,169 @@ Configfns cf[] = {
   {"PAGEEXCLUDE", &configexc, (void *)&(opts.ispagehead)},
   {"ROBOTINCLUDE", &configinc, (void *)&(opts.robots)},
   {"ROBOTEXCLUDE", &configexc, (void *)&(opts.robots)},
-  {"REQSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_REQ)])},
-  {"REQARGSSORTBY", &configchoice,
+  {"REQSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_REQ)])},
+  {"REQARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_REQ)])},
-  {"REDIRSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_REDIR)])},
-  {"REDIRARGSSORTBY", &configchoice,
+  {"REDIRSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_REDIR)])},
+  {"REDIRARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_REDIR)])},
-  {"FAILSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_FAIL)])},
-  {"FAILARGSSORTBY", &configchoice,
+  {"FAILSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_FAIL)])},
+  {"FAILARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_FAIL)])},
-  {"TYPESORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_TYPE)])},
-  {"SUBTYPESORTBY", &configchoice,
+  {"TYPESORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_TYPE)])},
+  {"SUBTYPESORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_TYPE)])},
-  {"DIRSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_DIR)])},
-  {"SUBDIRSORTBY", &configchoice,
+  {"DIRSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_DIR)])},
+  {"SUBDIRSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_DIR)])},
-  {"HOSTSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_HOST)])},
-  {"REDIRHOSTSORTBY", &configchoice,
+  {"HOSTSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_HOST)])},
+  {"REDIRHOSTSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_REDIRHOST)])},
-  {"FAILHOSTSORTBY", &configchoice,
+  {"FAILHOSTSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_FAILHOST)])},
-  {"DOMSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_DOM)])},
-  {"SUBDOMSORTBY", &configchoice,
+  {"DOMSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_DOM)])},
+  {"SUBDOMSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_DOM)])},
-  {"ORGSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_ORG)])},
-  {"SUBORGSORTBY", &configchoice,
+  {"ORGSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_ORG)])},
+  {"SUBORGSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_ORG)])},
-  {"REFSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_REF)])},
-  {"REFARGSSORTBY", &configchoice,
+  {"REFSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_REF)])},
+  {"REFARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_REF)])},
-  {"REFSITESORTBY", &configchoice,
+  {"REFSITESORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_REFSITE)])},
-  {"REFDIRSORTBY", &configchoice,
+  {"REFDIRSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_REFSITE)])},
-  {"REDIRREFSORTBY", &configchoice,
+  {"REDIRREFSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_REDIRREF)])},
-  {"REDIRREFARGSSORTBY", &configchoice,
+  {"REDIRREFARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_REDIRREF)])},
-  {"FAILREFSORTBY", &configchoice,
+  {"FAILREFSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_FAILREF)])},
-  {"FAILREFARGSSORTBY", &configchoice,
+  {"FAILREFARGSSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_FAILREF)])},
-  {"BROWREPSORTBY", &configchoice,
+  {"BROWREPSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_BROWREP)])},
-  {"FULLBROWSORTBY", &configchoice,
+  {"FULLBROWSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_BROWREP)])},
-  {"BROWSUMSORTBY", &configchoice,
+  {"BROWSUMSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_BROWSUM)])},
-  {"BROWSORTBY", &configchoice,
+  {"BROWSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_BROWSUM)])},
-  {"SUBBROWSORTBY", &configchoice,
+  {"SUBBROWSORTBY", &configsortby,
    (void *)&(opts.outopts.subsortby[G(REP_BROWSUM)])},
-  {"OSSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_OS)])},
-  {"SUBOSSORTBY", &configchoice, (void *)&(opts.outopts.subsortby[G(REP_OS)])},
-  {"STATUSSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_CODE)])},
-  {"VHOSTSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_VHOST)])},
-  {"REDIRVHOSTSORTBY", &configchoice,
+  {"OSSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_OS)])},
+  {"SUBOSSORTBY", &configsortby, (void *)&(opts.outopts.subsortby[G(REP_OS)])},
+  {"STATUSSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_CODE)])},
+  {"VHOSTSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_VHOST)])},
+  {"REDIRVHOSTSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_REDIRVHOST)])},
-  {"FAILVHOSTSORTBY", &configchoice,
+  {"FAILVHOSTSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_FAILVHOST)])},
-  {"USERSORTBY", &configchoice, (void *)&(opts.outopts.sortby[G(REP_USER)])},
-  {"REDIRUSERSORTBY", &configchoice,
+  {"USERSORTBY", &configsortby, (void *)&(opts.outopts.sortby[G(REP_USER)])},
+  {"REDIRUSERSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_REDIRUSER)])},
-  {"FAILUSERSORTBY", &configchoice,
+  {"FAILUSERSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_FAILUSER)])},
-  {"SEARCHQUERYSORTBY", &configchoice,
+  {"SEARCHQUERYSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_SEARCHREP)])},
-  {"SEARCHWORDSORTBY", &configchoice,
+  {"SEARCHWORDSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_SEARCHSUM)])},
-  {"INTSEARCHQUERYSORTBY", &configchoice,
+  {"INTSEARCHQUERYSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_INTSEARCHREP)])},
-  {"INTSEARCHWORDSORTBY", &configchoice,
+  {"INTSEARCHWORDSORTBY", &configsortby,
    (void *)&(opts.outopts.sortby[G(REP_INTSEARCHSUM)])},
   {"ALL", &configall, (void *)(opts.outopts.repq)},
   {"ALLBACK", &configallback, (void *)(opts.outopts.back)},
-  {"YEARLY", &configchoice, (void *)&(opts.outopts.repq[REP_YEAR])},
-  {"QUARTERLY", &configchoice, (void *)&(opts.outopts.repq[REP_QUARTERLY])},
-  {"MONTHLY", &configchoice, (void *)&(opts.outopts.repq[REP_MONTH])},
-  {"WEEKLY", &configchoice, (void *)&(opts.outopts.repq[REP_WEEK])},
-  {"DAILYREP", &configchoice, (void *)&(opts.outopts.repq[REP_DAYREP])},
-  {"FULLDAILY", &configchoice, (void *)&(opts.outopts.repq[REP_DAYREP])},
-  {"DAILYSUM", &configchoice, (void *)&(opts.outopts.repq[REP_DAYSUM])},
-  {"DAILY", &configchoice, (void *)&(opts.outopts.repq[REP_DAYSUM])},
-  {"HOURLYREP", &configchoice, (void *)&(opts.outopts.repq[REP_HOURREP])},
-  {"FULLHOURLY", &configchoice, (void *)&(opts.outopts.repq[REP_HOURREP])},
-  {"HOURLYSUM", &configchoice, (void *)&(opts.outopts.repq[REP_HOURSUM])},
-  {"HOURLY", &configchoice, (void *)&(opts.outopts.repq[REP_HOURSUM])},
-  {"WEEKHOUR", &configchoice, (void *)&(opts.outopts.repq[REP_WEEKHOUR])},
-  {"QUARTERREP", &configchoice, (void *)&(opts.outopts.repq[REP_QUARTERREP])},
-  {"QUARTER", &configchoice, (void *)&(opts.outopts.repq[REP_QUARTERREP])},
-  {"QUARTERSUM", &configchoice, (void *)&(opts.outopts.repq[REP_QUARTERSUM])},
-  {"FIVEREP", &configchoice, (void *)&(opts.outopts.repq[REP_FIVEREP])},
-  {"FIVE", &configchoice, (void *)&(opts.outopts.repq[REP_FIVEREP])},
-  {"FIVESUM", &configchoice, (void *)&(opts.outopts.repq[REP_FIVESUM])},
-  {"GENERAL", &configchoice, (void *)&(opts.outopts.repq[REP_GENSUM])},
-  {"LASTSEVEN", &configchoice, (void *)&(opts.outopts.last7)},
-  {"RUNTIME", &configchoice, (void *)&(opts.outopts.runtime)},
-  {"GOTOS", &configchoice, (void *)&(opts.outopts.gotos)},
-  {"REPORTSPAN", &configchoice, (void *)&(opts.outopts.repspan)},
+  {"YEARLY", &configonoff, (void *)&(opts.outopts.repq[REP_YEAR])},
+  {"QUARTERLY", &configonoff, (void *)&(opts.outopts.repq[REP_QUARTERLY])},
+  {"MONTHLY", &configonoff, (void *)&(opts.outopts.repq[REP_MONTH])},
+  {"WEEKLY", &configonoff, (void *)&(opts.outopts.repq[REP_WEEK])},
+  {"DAILYREP", &configonoff, (void *)&(opts.outopts.repq[REP_DAYREP])},
+  {"FULLDAILY", &configonoff, (void *)&(opts.outopts.repq[REP_DAYREP])},
+  {"DAILYSUM", &configonoff, (void *)&(opts.outopts.repq[REP_DAYSUM])},
+  {"DAILY", &configonoff, (void *)&(opts.outopts.repq[REP_DAYSUM])},
+  {"HOURLYREP", &configonoff, (void *)&(opts.outopts.repq[REP_HOURREP])},
+  {"FULLHOURLY", &configonoff, (void *)&(opts.outopts.repq[REP_HOURREP])},
+  {"HOURLYSUM", &configonoff, (void *)&(opts.outopts.repq[REP_HOURSUM])},
+  {"HOURLY", &configonoff, (void *)&(opts.outopts.repq[REP_HOURSUM])},
+  {"WEEKHOUR", &configonoff, (void *)&(opts.outopts.repq[REP_WEEKHOUR])},
+  {"QUARTERREP", &configonoff, (void *)&(opts.outopts.repq[REP_QUARTERREP])},
+  {"QUARTER", &configonoff, (void *)&(opts.outopts.repq[REP_QUARTERREP])},
+  {"QUARTERSUM", &configonoff, (void *)&(opts.outopts.repq[REP_QUARTERSUM])},
+  {"FIVEREP", &configonoff, (void *)&(opts.outopts.repq[REP_FIVEREP])},
+  {"FIVE", &configonoff, (void *)&(opts.outopts.repq[REP_FIVEREP])},
+  {"FIVESUM", &configonoff, (void *)&(opts.outopts.repq[REP_FIVESUM])},
+  {"GENERAL", &configonoff, (void *)&(opts.outopts.repq[REP_GENSUM])},
+  {"LASTSEVEN", &configonoff, (void *)&(opts.outopts.last7)},
+  {"RUNTIME", &configonoff, (void *)&(opts.outopts.runtime)},
+  {"GOTOS", &configgotos, (void *)&(opts.outopts.gotos)},
+  {"REPORTSPAN", &configonoff, (void *)&(opts.outopts.repspan)},
   {"REPORTSPANTHRESHOLD", &configuint, (void *)&(opts.outopts.rsthresh)},
   {"RSTHRESH", &configuint, (void *)&(opts.outopts.rsthresh)},
-  {"DESCRIPTIONS", &configchoice, (void *)&(opts.outopts.descriptions)},
-  {"REQUEST", &configchoice, (void *)&(opts.outopts.repq[REP_REQ])},
-  {"REDIR", &configchoice, (void *)&(opts.outopts.repq[REP_REDIR])},
-  {"REDIRECTION", &configchoice, (void *)&(opts.outopts.repq[REP_REDIR])},
-  {"FAILURE", &configchoice, (void *)&(opts.outopts.repq[REP_FAIL])},
-  {"FILETYPE", &configchoice, (void *)&(opts.outopts.repq[REP_TYPE])},
-  {"SIZE", &configchoice, (void *)&(opts.outopts.repq[REP_SIZE])},
-  {"PROCTIME", &configchoice, (void *)&(opts.outopts.repq[REP_PROCTIME])},
-  {"DIRECTORY", &configchoice, (void *)&(opts.outopts.repq[REP_DIR])},
-  {"HOST", &configchoice, (void *)&(opts.outopts.repq[REP_HOST])},
-  {"REDIRHOST", &configchoice, (void *)&(opts.outopts.repq[REP_REDIRHOST])},
-  {"FAILHOST", &configchoice, (void *)&(opts.outopts.repq[REP_FAILHOST])},
-  {"DOMAIN", &configchoice, (void *)&(opts.outopts.repq[REP_DOM])},
-  {"ORGANISATION", &configchoice, (void *)&(opts.outopts.repq[REP_ORG])},
-  {"ORGANIZATION", &configchoice, (void *)&(opts.outopts.repq[REP_ORG])},
-  {"REFERRER", &configchoice, (void *)&(opts.outopts.repq[REP_REF])},
-  {"REFERER", &configchoice, (void *)&(opts.outopts.repq[REP_REF])},
-  {"REFSITE", &configchoice, (void *)&(opts.outopts.repq[REP_REFSITE])},
-  {"REDIRREF", &configchoice, (void *)&(opts.outopts.repq[REP_REDIRREF])},
-  {"FAILREF", &configchoice, (void *)&(opts.outopts.repq[REP_FAILREF])},
-  {"BROWSERREP", &configchoice, (void *)&(opts.outopts.repq[REP_BROWREP])},
-  {"BROWREP", &configchoice, (void *)&(opts.outopts.repq[REP_BROWREP])},
-  {"FULLBROWSER", &configchoice, (void *)&(opts.outopts.repq[REP_BROWREP])},
-  {"BROWSERSUM", &configchoice, (void *)&(opts.outopts.repq[REP_BROWSUM])},
-  {"BROWSUM", &configchoice, (void *)&(opts.outopts.repq[REP_BROWSUM])},
-  {"BROWSER", &configchoice, (void *)&(opts.outopts.repq[REP_BROWSUM])},
-  {"OSREP", &configchoice, (void *)&(opts.outopts.repq[REP_OS])},
-  {"VHOST", &configchoice, (void *)&(opts.outopts.repq[REP_VHOST])},
-  {"REDIRVHOST", &configchoice, (void *)&(opts.outopts.repq[REP_REDIRVHOST])},
-  {"FAILVHOST", &configchoice, (void *)&(opts.outopts.repq[REP_FAILVHOST])},
-  {"USER", &configchoice, (void *)&(opts.outopts.repq[REP_USER])},
-  {"REDIRUSER", &configchoice, (void *)&(opts.outopts.repq[REP_REDIRUSER])},
-  {"FAILUSER", &configchoice, (void *)&(opts.outopts.repq[REP_FAILUSER])},
-  {"SEARCHQUERY", &configchoice, (void *)&(opts.outopts.repq[REP_SEARCHREP])},
-  {"SEARCHWORD", &configchoice, (void *)&(opts.outopts.repq[REP_SEARCHSUM])},
-  {"INTSEARCHQUERY", &configchoice,
+  {"DESCRIPTIONS", &configonoff, (void *)&(opts.outopts.descriptions)},
+  {"REQUEST", &configonoff, (void *)&(opts.outopts.repq[REP_REQ])},
+  {"REDIR", &configonoff, (void *)&(opts.outopts.repq[REP_REDIR])},
+  {"REDIRECTION", &configonoff, (void *)&(opts.outopts.repq[REP_REDIR])},
+  {"FAILURE", &configonoff, (void *)&(opts.outopts.repq[REP_FAIL])},
+  {"FILETYPE", &configonoff, (void *)&(opts.outopts.repq[REP_TYPE])},
+  {"SIZE", &configonoff, (void *)&(opts.outopts.repq[REP_SIZE])},
+  {"PROCTIME", &configonoff, (void *)&(opts.outopts.repq[REP_PROCTIME])},
+  {"DIRECTORY", &configonoff, (void *)&(opts.outopts.repq[REP_DIR])},
+  {"HOST", &configonoff, (void *)&(opts.outopts.repq[REP_HOST])},
+  {"REDIRHOST", &configonoff, (void *)&(opts.outopts.repq[REP_REDIRHOST])},
+  {"FAILHOST", &configonoff, (void *)&(opts.outopts.repq[REP_FAILHOST])},
+  {"DOMAIN", &configonoff, (void *)&(opts.outopts.repq[REP_DOM])},
+  {"ORGANISATION", &configonoff, (void *)&(opts.outopts.repq[REP_ORG])},
+  {"ORGANIZATION", &configonoff, (void *)&(opts.outopts.repq[REP_ORG])},
+  {"REFERRER", &configonoff, (void *)&(opts.outopts.repq[REP_REF])},
+  {"REFERER", &configonoff, (void *)&(opts.outopts.repq[REP_REF])},
+  {"REFSITE", &configonoff, (void *)&(opts.outopts.repq[REP_REFSITE])},
+  {"REDIRREF", &configonoff, (void *)&(opts.outopts.repq[REP_REDIRREF])},
+  {"FAILREF", &configonoff, (void *)&(opts.outopts.repq[REP_FAILREF])},
+  {"BROWSERREP", &configonoff, (void *)&(opts.outopts.repq[REP_BROWREP])},
+  {"BROWREP", &configonoff, (void *)&(opts.outopts.repq[REP_BROWREP])},
+  {"FULLBROWSER", &configonoff, (void *)&(opts.outopts.repq[REP_BROWREP])},
+  {"BROWSERSUM", &configonoff, (void *)&(opts.outopts.repq[REP_BROWSUM])},
+  {"BROWSUM", &configonoff, (void *)&(opts.outopts.repq[REP_BROWSUM])},
+  {"BROWSER", &configonoff, (void *)&(opts.outopts.repq[REP_BROWSUM])},
+  {"OSREP", &configonoff, (void *)&(opts.outopts.repq[REP_OS])},
+  {"VHOST", &configonoff, (void *)&(opts.outopts.repq[REP_VHOST])},
+  {"REDIRVHOST", &configonoff, (void *)&(opts.outopts.repq[REP_REDIRVHOST])},
+  {"FAILVHOST", &configonoff, (void *)&(opts.outopts.repq[REP_FAILVHOST])},
+  {"USER", &configonoff, (void *)&(opts.outopts.repq[REP_USER])},
+  {"REDIRUSER", &configonoff, (void *)&(opts.outopts.repq[REP_REDIRUSER])},
+  {"FAILUSER", &configonoff, (void *)&(opts.outopts.repq[REP_FAILUSER])},
+  {"SEARCHQUERY", &configonoff, (void *)&(opts.outopts.repq[REP_SEARCHREP])},
+  {"SEARCHWORD", &configonoff, (void *)&(opts.outopts.repq[REP_SEARCHSUM])},
+  {"INTSEARCHQUERY", &configonoff,
    (void *)&(opts.outopts.repq[REP_INTSEARCHREP])},
-  {"INTSEARCHWORD", &configchoice,
+  {"INTSEARCHWORD", &configonoff,
    (void *)&(opts.outopts.repq[REP_INTSEARCHSUM])},
-  {"STATUS", &configchoice, (void *)&(opts.outopts.repq[REP_CODE])},
-  {"YEARBACK", &configchoice, (void *)&(opts.outopts.back[REP_YEAR])},
-  {"QUARTERLYBACK", &configchoice,
-   (void *)&(opts.outopts.back[REP_QUARTERLY])},
-  {"MONTHBACK", &configchoice, (void *)&(opts.outopts.back[REP_MONTH])},
-  {"WEEKBACK", &configchoice, (void *)&(opts.outopts.back[REP_WEEK])},
-  {"DAYBACK", &configchoice, (void *)&(opts.outopts.back[REP_DAYREP])},
-  {"DAYREPBACK", &configchoice, (void *)&(opts.outopts.back[REP_DAYREP])},
-  {"FULLDAYBACK", &configchoice, (void *)&(opts.outopts.back[REP_DAYREP])},
-  {"HOURBACK", &configchoice, (void *)&(opts.outopts.back[REP_HOURREP])},
-  {"HOURREPBACK", &configchoice, (void *)&(opts.outopts.back[REP_HOURREP])},
-  {"FULLHOURBACK", &configchoice, (void *)&(opts.outopts.back[REP_HOURREP])},
-  {"QUARTERBACK", &configchoice, (void *)&(opts.outopts.back[REP_QUARTERREP])},
-  {"QUARTERREPBACK", &configchoice,
+  {"STATUS", &configonoff, (void *)&(opts.outopts.repq[REP_CODE])},
+  {"YEARBACK", &configonoff, (void *)&(opts.outopts.back[REP_YEAR])},
+  {"QUARTERLYBACK", &configonoff, (void *)&(opts.outopts.back[REP_QUARTERLY])},
+  {"MONTHBACK", &configonoff, (void *)&(opts.outopts.back[REP_MONTH])},
+  {"WEEKBACK", &configonoff, (void *)&(opts.outopts.back[REP_WEEK])},
+  {"DAYBACK", &configonoff, (void *)&(opts.outopts.back[REP_DAYREP])},
+  {"DAYREPBACK", &configonoff, (void *)&(opts.outopts.back[REP_DAYREP])},
+  {"FULLDAYBACK", &configonoff, (void *)&(opts.outopts.back[REP_DAYREP])},
+  {"HOURBACK", &configonoff, (void *)&(opts.outopts.back[REP_HOURREP])},
+  {"HOURREPBACK", &configonoff, (void *)&(opts.outopts.back[REP_HOURREP])},
+  {"FULLHOURBACK", &configonoff, (void *)&(opts.outopts.back[REP_HOURREP])},
+  {"QUARTERBACK", &configonoff, (void *)&(opts.outopts.back[REP_QUARTERREP])},
+  {"QUARTERREPBACK", &configonoff,
    (void *)&(opts.outopts.back[REP_QUARTERREP])},
-  {"FIVEBACK", &configchoice, (void *)&(opts.outopts.back[REP_FIVEREP])},
-  {"FIVEREPBACK", &configchoice, (void *)&(opts.outopts.back[REP_FIVEREP])},
-  {"RAWBYTES", &configchoice, (void *)&(opts.outopts.rawbytes)},
-  {"NOROBOTS", &configchoice, (void *)&(opts.outopts.norobots)},
-  {"SETTINGS", &configchoice, (void *)&vblesonly},
-  {"CGI", &configchoice, (void *)&cgi},
-  {"OUTPUT", &configchoice, (void *)&(opts.outopts.outstyle)},
-  {"PDFLATEX", &configchoice, (void *)&(opts.outopts.pdflatex)},
-  {"CASE", &configchoice, (void *)&(opts.miscopts.case_insensitive)},
-  {"USERCASE", &configchoice, (void *)&(opts.miscopts.usercase_insensitive)},
-  {"SEARCHCHARCONVERT", &configchoice, (void *)&(opts.outopts.searchconv)},
+  {"FIVEBACK", &configonoff, (void *)&(opts.outopts.back[REP_FIVEREP])},
+  {"FIVEREPBACK", &configonoff, (void *)&(opts.outopts.back[REP_FIVEREP])},
+  {"RAWBYTES", &configonoff, (void *)&(opts.outopts.rawbytes)},
+  {"NOROBOTS", &configonoff, (void *)&(opts.outopts.norobots)},
+  {"SETTINGS", &configonoff, (void *)&vblesonly},
+  {"CGI", &configonoff, (void *)&cgi},
+  {"OUTPUT", &configoutstyle, (void *)&(opts.outopts.outstyle)},
+  {"CASE", &configcase, (void *)&(opts.miscopts.case_insensitive)},
+  {"USERCASE", &configcase, (void *)&(opts.miscopts.usercase_insensitive)},
+  {"SEARCHCHARCONVERT", &configonoff, (void *)&(opts.outopts.searchconv)},
   {"YEARROWS", &configuint, (void *)&(opts.outopts.rows[REP_YEAR])},
   {"QUARTERLYROWS", &configuint, (void *)&(opts.outopts.rows[REP_QUARTERLY])},
   {"MONTHROWS", &configuint, (void *)&(opts.outopts.rows[REP_MONTH])},
@@ -1056,7 +1053,7 @@ Configfns cf[] = {
   {"MINGRAPHWIDTH", &configuint, (void *)&(opts.outopts.mingraphwidth)},
   {"ERRLINELENGTH", &configuint, (void *)&errwidth},
   {"PROGRESSFREQ", &configulong, (void *)&progressfreq},
-  {"WEEKBEGINSON", &configchoice, (void *)&(opts.outopts.weekbeginson)},
+  {"WEEKBEGINSON", &configweekday, (void *)&(opts.outopts.weekbeginson)},
   {"FROM", &configstr, (void *)&(opts.dman.fromstr)},
   {"TO", &configstr, (void *)&(opts.dman.tostr)},
   {"REPORTORDER", &configrepord, (void *)(opts.outopts.reporder)},
@@ -1065,7 +1062,7 @@ Configfns cf[] = {
   {"GENSUMLINES", &configdebug, (void *)&(opts.outopts.gensumlines)},
   {"DOMLEVEL", &configdomlevel, (void *)&domlevels},
 #ifndef NODNS
-  {"DNS", &configchoice, (void *)&dnslevel},
+  {"DNS", &configdns, (void *)&dnslevel},
   {"DNSFILE", &configstr, (void *)&dnsfile},
   {"DNSLOCKFILE", &configstr, (void *)&dnslockfile},
   {"DNSGOODHOURS", &configuint, (void *)&dnsgoodhrs},
@@ -1102,9 +1099,6 @@ void globals(char *comname) {
 #endif
 #ifdef SIGQUIT
   signal(SIGQUIT, sighandler);
-#endif
-#ifdef SIGPIPE
-  signal(SIGPIPE, SIG_IGN);
 #endif
   workspace = (char *)xmalloc(BLOCKSIZE);
   block_start = (char *)xmalloc(BLOCKSIZE + 1);  /* 1 for terminating char */
@@ -1134,9 +1128,9 @@ void globals(char *comname) {
   termchar[(unsigned char)'\0'] = TRUE;
 
   if (IS_EMPTY_STRING(comname))
-    COPYSTR(commandname, "analog")  /* no semicolon by defn of COPYSTR */
+    DEFAULTSTR(commandname, "analog")  /* no semicolon by defn of DEFAULTSTR */
   else
-    COPYSTR(commandname, comname);
+    DEFAULTSTR(commandname, comname);
 #ifndef NOFOLLOW
   commandpath = (char *)xmalloc(PATH_MAX);
   done = FALSE;
@@ -1367,7 +1361,7 @@ void globals(char *comname) {
   rep2colhead[REP_INTSEARCHREP] = search_;
   rep2colhead[REP_INTSEARCHSUM] = search_;
   rep2colhead[REP_CODE] = code_;
-  rep2busystr = (unsigned int *)xmalloc(DATEREPORTS_NUMBER * sizeof(unsigned int));
+  rep2busystr = (unsigned int *)xmalloc(DATEREP_NUMBER * sizeof(unsigned int));
   rep2busystr[REP_DAYREP] = busyday_;
   rep2busystr[REP_HOURREP] = busyhour_;
   rep2busystr[REP_QUARTERREP] = busyquarterhr_;
@@ -1499,13 +1493,13 @@ void defaults(Options *op) {
   confline(op, "CACHEFILE", CACHEFILE, NULL, -1);
   op->outopts.domainsfile = NULL;
   op->outopts.descfile = NULL;
-  COPYSTR(op->miscopts.dirsuffix, DIRSUFFIX);
+  DEFAULTSTR(op->miscopts.dirsuffix, DIRSUFFIX);
 #ifndef NODNS
   dnslevel = DNS;
   dnsgoodhrs = DNSGOODHOURS;
   dnsbadhrs = DNSBADHOURS;
-  COPYSTR(dnsfile, DNSFILE);
-  COPYSTR(dnslockfile, DNSLOCKFILE);
+  DEFAULTSTR(dnsfile, DNSFILE);
+  DEFAULTSTR(dnslockfile, DNSLOCKFILE);
 #ifndef NOALARM
   dnstimeout = DNSTIMEOUT;
 #endif
@@ -1515,13 +1509,11 @@ void defaults(Options *op) {
   op->outopts.searchconv = SEARCHCHARCONVERT;
   op->outopts.outstyle = OUTPUT;
   op->outopts.html = TRUE;
-  op->outopts.pdflatex = TRUE;
-  htmlstrlen = &htmlstrlen_normal;
-  COPYSTR(op->outopts.headerfile, HEADERFILE);
-  COPYSTR(op->outopts.footerfile, FOOTERFILE);
-  COPYSTR(op->outopts.outfile, OUTFILE);
-  COPYSTR(op->outopts.cacheoutfile, CACHEOUTFILE);
-  COPYSTR(op->outopts.imagedir, IMAGEDIR);
+  DEFAULTSTR(op->outopts.headerfile, HEADERFILE);
+  DEFAULTSTR(op->outopts.footerfile, FOOTERFILE);
+  DEFAULTSTR(op->outopts.outfile, OUTFILE);
+  DEFAULTSTR(op->outopts.cacheoutfile, CACHEOUTFILE);
+  DEFAULTSTR(op->outopts.imagedir, IMAGEDIR);
   op->outopts.chartdir = NULL;
   op->outopts.localchartdir = NULL;
   op->outopts.jpegcharts = FALSE;
@@ -1781,11 +1773,11 @@ void defaults(Options *op) {
   op->outopts.markchar = MARKCHAR;
   op->outopts.rawbytes = RAWBYTES;
   op->outopts.norobots = NOROBOTS;
-  COPYSTR(op->outopts.hostname, HOSTNAME);
-  COPYSTR(op->outopts.hosturl, HOSTURL);
+  DEFAULTSTR(op->outopts.hostname, HOSTNAME);
+  DEFAULTSTR(op->outopts.hosturl, HOSTURL);
   op->outopts.baseurl = NULL;
-  COPYSTR(op->outopts.logo, LOGO);
-  COPYSTR(op->outopts.stylesheet, STYLESHEET);
+  DEFAULTSTR(op->outopts.logo, LOGO);
+  DEFAULTSTR(op->outopts.stylesheet, STYLESHEET);
   op->outopts.weekbeginson = WEEKBEGINSON;
   op->outopts.plainpagewidth = PLAINPAGEWIDTH;
   op->outopts.htmlpagewidth = HTMLPAGEWIDTH;
@@ -1794,7 +1786,7 @@ void defaults(Options *op) {
   op->outopts.sepchar = (char)UNSET;
   op->outopts.repsepchar = (char)UNSET;
   op->outopts.decpt = (char)UNSET;
-  COPYSTR(op->outopts.compsep, COMPSEP);
+  DEFAULTSTR(op->outopts.compsep, COMPSEP);
   for (i = 0; i < GENREP_NUMBER; i++) {
     op->outopts.link[i] = NULL;
     op->outopts.wanthead[i] = NULL;
