@@ -1,4 +1,4 @@
-/***             analog 5.01             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -860,6 +860,7 @@ void finalinit(Options *op) {
   char *name, *alias;
   choice rc;
 #endif
+  extern htmlstrlenp htmlstrlen;
   extern timecode_t starttimeuxc;
   extern char *country[];
   extern Memman *xmemman;
@@ -942,12 +943,10 @@ void finalinit(Options *op) {
     }
     /* convert any date codes in CHARTDIRs */
     if (od->chartdir != NULL && od->localchartdir != NULL) {
-      s = (char *)xmalloc(datefmtlen(NULL, od->localchartdir, TRUE, TRUE) + 1);
-      (void)timesprintf(NULL, s, od->localchartdir, op->dman.last7to, TRUE);
-      od->localchartdir = s;
-      s = (char *)xmalloc(datefmtlen(NULL, od->chartdir, TRUE, TRUE) + 1);
-      (void)timesprintf(NULL, s, od->chartdir, op->dman.last7to, TRUE);
-      od->chartdir = s;
+      s = timesprintf(NULL, od->localchartdir, op->dman.last7to, TRUE);
+      DEFAULTSTR(od->localchartdir, s);
+      s = timesprintf(NULL, od->chartdir, op->dman.last7to, TRUE);
+      DEFAULTSTR(od->chartdir, s);
     }
   }
 #endif
@@ -992,6 +991,12 @@ void finalinit(Options *op) {
 	(lngstr[charset_])++;
 	od->html = FALSE;
       }
+      if (strcaseeq(lngstr[charset_], "UTF-8"))
+	htmlstrlen = &htmlstrlen_utf8;
+      else if (strcaseeq(lngstr[charset_], "ISO-2022-JP"))
+	htmlstrlen = &htmlstrlen_jis;
+      else
+	htmlstrlen = &htmlstrlen_normal;
       for (i = 0; i < 7; i++)
 	DEFAULTSTR(od->dayname[i], nextlngstr(tempf, od->lang.file, TRUE));
       for (i = 0; i < 12; i++)
@@ -1002,6 +1007,8 @@ void finalinit(Options *op) {
       /* This final nextlngstr() checks the language file isn't too long */
       od->plainmonthlen = arraymaxlen(od->monthname, 12, ASCII);
       /* plain is longer: by pretending to be ASCII it includes whole strlen */
+      /* But note that even this is not enough for formatted dates: could need
+	 max_ascii_len + (max_html_len - min_html_len) to apply spacing */
       od->monthlen = arraymaxlen(od->monthname, 12, outstyle);
       od->plaindaylen = arraymaxlen(od->dayname, 7, ASCII);
       od->daylen = arraymaxlen(od->dayname, 7, outstyle);
