@@ -1,4 +1,4 @@
-/***             analog 5.01             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -501,16 +501,20 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     /* lang->code = BOSNIAN; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "BULGARIAN"))
     lang->code = BULGARIAN;
+  else if (strcaseeq(arg1, "BULGARIAN-MIK"))
+    lang->code = BULGARIAN_MIK;
   else if (strcaseeq(arg1, "CATALAN"))
     lang->code = CATALAN;
   else if (strcaseeq(arg1, "SIMP-CHINESE") || strcaseeq(arg1, "CHINESE"))
     /* lang->code = SIMP_CHINESE; */ oldlang = TRUE;
-  else if (strcaseeq(arg1, "TRAD-CHINESE"))
-    /* lang->code = TRAD_CHINESE; */ oldlang = TRUE;
+  else if (strcaseeq(arg1, "TRAD-CHINESE") || strcaseeq(arg1, "TAIWANESE"))
+    lang->code = TRAD_CHINESE;
   else if (strcaseeq(arg1, "CROATIAN"))
     /* lang->code = CROATIAN; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "CZECH"))
     lang->code = CZECH;
+  else if (strcaseeq(arg1, "CZECH-1250"))
+    lang->code = CZECH_1250;
   else if (strcaseeq(arg1, "DANISH"))
     lang->code = DANISH;
   else if (strcaseeq(arg1, "FLEMISH") || strcaseeq(arg1, "DUTCH"))
@@ -533,8 +537,14 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     /* lang->code = ICELANDIC; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "ITALIAN"))
     lang->code = ITALIAN;
-  else if (strcaseeq(arg1, "JAPANESE"))
-    lang->code = JAPANESE;
+  else if (strcaseeq(arg1, "JAPANESE-EUC"))
+    lang->code = JAPANESE_EUC;
+  else if (strcaseeq(arg1, "JAPANESE-JIS") || strcaseeq(arg1, "JAPANESE"))
+    lang->code = JAPANESE_JIS;
+  else if (strcaseeq(arg1, "JAPANESE-SJIS"))
+    lang->code = JAPANESE_SJIS;
+  else if (strcaseeq(arg1, "JAPANESE-UTF"))
+    lang->code = JAPANESE_UTF;
   else if (strcaseeq(arg1, "KOREAN"))
     lang->code = KOREAN;
   else if (strcaseeq(arg1, "LATVIAN"))
@@ -549,8 +559,9 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     lang->code = POLISH;
   else if (strcaseeq(arg1, "PORTUGUESE") || strcaseeq(arg1, "PORTUGESE"))
     lang->code = PORTUGUESE;
-  else if (strcaseeq(arg1, "BR-PORTUGUESE") || strcaseeq(arg1, "BR-PORTUGESE"))
-    /* lang->code = BR_PORTUGUESE; */ oldlang = TRUE;
+  else if (strcaseeq(arg1, "BR-PORTUGUESE") || strcaseeq(arg1, "BR-PORTUGESE")
+	   || strcaseeq(arg1, "BRAZILIAN"))
+    lang->code = BR_PORTUGUESE;
   else if (strcaseeq(arg1, "ROMANIAN"))
     /* lang->code = ROMANIAN; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "RUSSIAN"))
@@ -562,10 +573,15 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     /* lang->code = SLOVAK; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "SLOVENE") || strcaseeq(arg1, "SLOVENIAN"))
     lang->code = SLOVENE;
+  else if (strcaseeq(arg1, "SLOVENE-1250") ||
+	   strcaseeq(arg1, "SLOVENIAN-1250"))
+    lang->code = SLOVENE_1250;
   else if (strcaseeq(arg1, "SPANISH"))
     /* lang->code = SPANISH; */ oldlang = TRUE;
   else if (strcaseeq(arg1, "SWEDISH"))
     lang->code = SWEDISH;
+  else if (strcaseeq(arg1, "SWEDISH-ALT"))
+    lang->code = SWEDISH_ALT;
   else if (strcaseeq(arg1, "TURKISH"))
     lang->code = TURKISH;
   else if (strcaseeq(arg1, "UKRAINIAN") || strcaseeq(arg1, "UKRANIAN"))
@@ -689,13 +705,23 @@ void configlogfmt(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     configlogfmt(opt, NULL, LOG_COMBINED2, NULL, -1);
     configlogfmt(opt, NULL, LOG_COMBINED3, NULL, -1);
   }
-  else if (strcaseeq(arg1, "MICROSOFT-NA")) {
-    configlogfmt(opt, NULL, LOG_MS_NA1, NULL, -1);
-    configlogfmt(opt, NULL, LOG_MS_NA2, NULL, -1);
+  else if (strcaseeq(arg1, "MICROSOFT-NA") ||
+	   strcaseeq(arg1, "MICROSOFT-NA2")) {
+    configlogfmt(opt, NULL, LOG_MS_NA2A, NULL, -1);
+    configlogfmt(opt, NULL, LOG_MS_NA2B, NULL, -1);
   }
-  else if (strcaseeq(arg1, "MICROSOFT-INT")) {
-    configlogfmt(opt, NULL, LOG_MS_INT1, NULL, -1);
-    configlogfmt(opt, NULL, LOG_MS_INT2, NULL, -1);
+  else if (strcaseeq(arg1, "MICROSOFT-NA4")) {
+    configlogfmt(opt, NULL, LOG_MS_NA4A, NULL, -1);
+    configlogfmt(opt, NULL, LOG_MS_NA4B, NULL, -1);
+  }
+  else if (strcaseeq(arg1, "MICROSOFT-INT") ||
+	   strcaseeq(arg1, "MICROSOFT-INT2")) {
+    configlogfmt(opt, NULL, LOG_MS_INT2A, NULL, -1);
+    configlogfmt(opt, NULL, LOG_MS_INT2B, NULL, -1);
+  }
+  else if (strcaseeq(arg1, "MICROSOFT-INT4")) {
+    configlogfmt(opt, NULL, LOG_MS_INT4A, NULL, -1);
+    configlogfmt(opt, NULL, LOG_MS_INT4B, NULL, -1);
   }
   else if (strcaseeq(arg1, "WEBSITE-NA"))
     configlogfmt(opt, NULL, LOG_WEBSITE_NA, NULL, -1);
