@@ -1,4 +1,4 @@
-/***             analog 5.01             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -96,7 +96,6 @@ int my_lfclose(FILE *f, Filelist *p, Filelist *allc, Filelist *allp,
   extern char *warn_args;
 
   unsigned long *data = p->data;
-  char *datestr;
   Filelist *ap, *nextap;
   Inputformatlist *fmt;
   choice count[INPUT_NUMBER];
@@ -135,13 +134,10 @@ int my_lfclose(FILE *f, Filelist *p, Filelist *allc, Filelist *allp,
       debug('S', "Times in %s offset by +%d minutes", filetype, p->tz);
     else if (p->tz < 0)
       debug('S', "Times in %s offset by %d minutes", filetype, p->tz);
-    datestr =
-      (char *)xmalloc(datefmtlen(NULL, LFCLOSE_DATEFMT, TRUE, FALSE) + 1);
     debug('S', "Earliest entry in %s: %s", filetype,
-	  timesprintf(NULL, datestr, LFCLOSE_DATEFMT, p->from, FALSE));
+	  timesprintf(NULL, LFCLOSE_DATEFMT, p->from, FALSE));
     debug('S', "Latest entry in %s: %s", filetype,
-	  timesprintf(NULL, datestr, LFCLOSE_DATEFMT, p->to, FALSE));
-    free((void *)datestr);
+	  timesprintf(NULL, LFCLOSE_DATEFMT, p->to, FALSE));
     if (allp == NULL) {
       p->format->count[ITEM_FILE] = 2;  /* good enough for date check */
       count[ITEM_FILE] = 2;
@@ -956,20 +952,39 @@ choice parselogfmt(FILE *f, void *arg, char c) {
 	x = x * 10 + (*(e++) - '0');
       y = (*(++e) - '0');
       if (*(++e) != '/')
-	y = y * 10 + (*e - '0');
+	y = y * 10 + (*(e++) - '0');
+      e += 3;
       if (x <= 12 && y > 12) {
-	debug('F',
-	      "  Detect that it's in Microsoft format (North American dates)");
-	configlogfmt((void *)&logformat, NULL, "MICROSOFT-NA", NULL, -1);
+	if (*e == ',') {
+	  debug('F', "  Detect that it's in Microsoft format "
+		"(North American dates, two-digit years)");
+	  configlogfmt((void *)&logformat, NULL, "MICROSOFT-NA2", NULL, -1);
+	}
+	else {
+	  debug('F', "  Detect that it's in Microsoft format "
+		"(North American dates, four-digit years)");
+	  configlogfmt((void *)&logformat, NULL, "MICROSOFT-NA4", NULL, -1);
+	}
       }
       else if (x > 12 && y <= 12) {
-	debug('F',
-	      "  Detect that it's in Microsoft format (international dates)");
-	configlogfmt((void *)&logformat, NULL, "MICROSOFT-INT", NULL, -1);
+	if (*e == ',') {
+	  debug('F', "  Detect that it's in Microsoft format "
+		"(international dates, two-digit years)");
+	  configlogfmt((void *)&logformat, NULL, "MICROSOFT-INT2", NULL, -1);
+	}
+	else {
+	  debug('F', "  Detect that it's in Microsoft format "
+		"(international dates, four-digit years)");
+	  configlogfmt((void *)&logformat, NULL, "MICROSOFT-INT4", NULL, -1);
+	}
       }
       else {
-	warn('F', TRUE, "Microsoft logfile with ambiguous dates: "
-	     "use LOGFORMAT MICROSOFT-NA or LOGFORMAT MICROSOFT-INT");
+	if (*e == ',')
+	  warn('F', TRUE, "Microsoft logfile with ambiguous dates: "
+	       "use LOGFORMAT MICROSOFT-NA2 or LOGFORMAT MICROSOFT-INT2");
+	else
+	  warn('F', TRUE, "Microsoft logfile with ambiguous dates: "
+	       "use LOGFORMAT MICROSOFT-NA4 or LOGFORMAT MICROSOFT-INT4");
 	*d = '\n';
 	return(BADLOGFMT);
       }
