@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -19,14 +19,14 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
   choice outstyle = od->outstyle;
   char *compsep = od->compsep;
   char **lngstr = od->lngstr;
-  char *charset = lngstr[charset_];
 
   double t0;
   int t1, t2;
 
   if (cgi) {
     if (outstyle == HTML)
-      fprintf(outf, "Content-Type: text/html; charset=%s\n\n", charset);
+      fprintf(outf, "Content-Type: text/html; charset=%s\n\n",
+	      lngstr[charset_]);
     else
       fprintf(outf, "Content-Type: text/plain\n\n");
   }
@@ -34,7 +34,7 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
     fputs("<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML 2.0//EN\">\n", outf);
     fputs("<html>\n<head>\n", outf);
     fprintf(outf, "<meta http-equiv=\"Content-Type\" "
-	    "content=\"text/html; charset=%s\">\n", charset);
+	    "content=\"text/html; charset=%s\">\n", lngstr[charset_]);
     if (od->norobots)
       fputs("<meta name=\"robots\" content=\"noindex,nofollow\">\n", outf);
     fprintf(outf, "<meta name=\"GENERATOR\" content=\"analog %s\">\n",
@@ -79,15 +79,8 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
   }
   else if (outstyle == LATEX) {
     fputs("\\documentclass{article}\n", outf);
-    if (!strcaseeq(lngstr[charset_], "US-ASCII")) {
-      /* Charset US-ASCII or ISO-8859-[12] enforced in init.c */
-      fprintf(outf, "\\usepackage[latin%c]{inputenc}\n", charset[9]);
-      fputs("\\usepackage[T1]{fontenc}\n", outf);
-    }
-    if (od->pdflatex)
-      fputs("\\usepackage[pdftex]{color}\n", outf);
-    else
-      fputs("\\usepackage[dvips]{color}\n", outf);
+    fputs("\\usepackage{isolatin1}\n", outf);  /* safe even in ASCII charset */
+    fputs("\\usepackage[dvips]{color}\n", outf);
     fputs("\\definecolor{barcolour}{rgb}{0.75,0.2,0.2}\n", outf);
     fputs("\\newsavebox{\\ttchar}\n", outf);
     fputs("\\sbox{\\ttchar}{\\mbox{\\tt -}}\n", outf);
@@ -452,6 +445,7 @@ void timerep(FILE *outf, Outchoices *od, choice rep, Dateman *dman,
 	     hr, min, busydate + intlength, newhr, newmin, graphby);
 }
 
+
 void timesum(FILE *outf, Outchoices *od, choice rep, Dateman *dman,
 	     unsigned int granularity) {
   unsigned int repgran = rep2gran[rep];
@@ -551,8 +545,7 @@ void printtree(FILE *outf, Outchoices *od, choice rep, Hashtable *tree,
       need += strlen(pn->name);
     for (p = tree->head[0]; p != NULL; TO_NEXT(p)) {
       name = maketreename(partname, p, &pn, &s, need, rep, TRUE);
-      if (STREQ(name, LNGSTR_NODOMAIN) || STREQ(name, LNGSTR_UNKDOMAIN) ||
-	  ISDIGIT(name[strlen(name) - 1]))
+      if (name[0] == '\0' || name[1] == '\0')  /* in REP_ORG, a code */
 	rightalign = FALSE;
       else
 	rightalign = possrightalign;
@@ -857,23 +850,24 @@ void output(Outchoices *od, Hashindex **gooditems, Hashindex **baditems,
 	    choice datacols[ITEM_NUMBER][OUTCOME_NUMBER][DATACOLS_NUMBER][2],
 	    choice data2cols[ITEM_NUMBER][DATA_NUMBER], unsigned int *no_cols,
 	    unsigned int granularity) {
-  char *outfile = od->outfile;
-
+  char *filename = NULL;
   FILE *outf;
   int ro;
   choice rep;
 
   /* first open output file */
   
-  if (IS_STDOUT(outfile)) {
+  if (IS_STDOUT(od->outfile)) {
     outf = stdout;
     debug('F', "Opening stdout as output file");
   }
   else {
-    if ((outf = FOPENW(outfile)) == NULL)
-      error("failed to open output file %s for writing", outfile);
+    filename = timesprintf(NULL, od->outfile, dman->last7to, TRUE);
+    /* filename is used later, so must not use timesprintf in the mean time */
+    if ((outf = FOPENW(filename)) == NULL)
+      error("failed to open output file %s for writing", filename);
     else
-      debug('F', "Opening %s as output file", outfile);
+      debug('F', "Opening %s as output file", filename);
   }
 
   /* remove any reports not wanted */
@@ -961,8 +955,8 @@ void output(Outchoices *od, Hashindex **gooditems, Hashindex **baditems,
   /*** Bit at the bottom of the page ***/
 
   pagebot(outf, od);
-  if (!IS_STDOUT(outfile)) {
-    debug('F', "Closing %s", outfile);
+  if (!IS_STDOUT(od->outfile)) {
+    debug('F', "Closing %s", filename);
     fclose(outf);
   }
 }
