@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -499,7 +499,6 @@ char *datesprintf(Outchoices *od, char *fmt, datecode_t date, unsigned int hr,
   }
   code2date(date, &d, &m, &y);
   code2date(newdate, &d2, &m2, &y2);
-  ENSURE_LEN(ans, len, 1);  /* in case fmt is "" */
   for (c = fmt, s = ans; *c != '\0'; c++) {
     current = (ans == NULL)?0:(size_t)(s - ans);
     ENSURE_LEN(ans, len, current + increment);
@@ -607,7 +606,7 @@ char *datesprintf(Outchoices *od, char *fmt, datecode_t date, unsigned int hr,
     }    /* if *c == '%' */
     else
       PUTc(s, *c);
-  }  /* for c */
+  }
   *s = '\0';
   return(ans);
 }
@@ -872,9 +871,8 @@ unsigned int alphatreewidth(Outchoices *od, choice rep, Hashtable *tree,
     return(0);
   for (p = tree->head[0]; p != NULL; TO_NEXT(p)) {
     name = maketreename(partname, p, &pn, &s, need, rep, TRUE);
-    if (!STREQ(name, LNGSTR_NODOMAIN) && !STREQ(name, LNGSTR_UNKDOMAIN) &&
-	!ISDIGIT(name[strlen(name) - 1])) { /* ignore left-aligned ones */
-      strcpy(workspace, name);
+    if (name[0] != '\0' && name[1] != '\0') {   /* i.e. ignore special */
+      strcpy(workspace, name);                  /* left-aligned codes */
       do_aliasx(workspace, od->aliashead[G(rep)]);
       /* Only use do_aliasx() not do_aliasrep(), because it's just for
 	 measuring width. */
@@ -980,8 +978,6 @@ void whatincluded(FILE *outf, Outchoices *od, choice rep, unsigned long n,
 
   int firsts, firstds, alls, sorted, alphsort, unsort;
   char *lngs, *c;
-  static char *t = NULL;
-  static size_t tlen = 0;
   unsigned long temp = 0;
   timecode_t tempd;
 
@@ -1068,40 +1064,32 @@ void whatincluded(FILE *outf, Outchoices *od, choice rep, unsigned long n,
 	else {  /* floorqual != '\0' */
 	  doublemprintf(outf, outstyle, pagewidth, floormin, od->decpt);
 	  if (floorqual == '%') {
+	    if (outstyle == LATEX)
+	      fputc('\\', outf);
+	    /* The above is a real cheat. It translates % to \% by relying on
+	       the fact that all the following strings _start_ with %. In fact,
+	       this isn't true in Hungarian, but as the LaTeX output style only
+	       accepts ASCII and ISO-8859-1, this shouldn't be a problem.
+	       Unless someone specifies LANGFILE hua.lng. Or until another
+	       language file comes along and breaks this assumption. Oh well.
+	       The proper fix is much too difficult, unless this becomes a real
+	       problem. */
 	    if (floorby == REQUESTS)
-	      c = lngstr[method2pc[requests]];
+	      mprintf(outf, pagewidth, "%s", lngstr[method2pc[requests]]);
 	    else if (floorby == REQUESTS7)
-	      c = lngstr[method2pc[requests7]];
+	      mprintf(outf, pagewidth, "%s", lngstr[method2pc[requests7]]);
 	    else
-	      c = lngstr[method2pc[floorby]];
-	    if (outstyle == LATEX) { /* then change one % to \% -- yuk. */
-	      ENSURE_LEN(t, tlen, strlen(c) + 2);
-	      strcpy(t, c);
-	      if ((c = strchr(t, '%')) != NULL) {
-		memmove(c + 1, c, strlen(c) + 1);
-		*c = '\\';
-	      }
-	      c = t;
-	    }
-	    mprintf(outf, pagewidth, "%s", c);
+	      mprintf(outf, pagewidth, "%s", lngstr[method2pc[floorby]]);
 	  }
 	  else if (floorqual == ':') {
+	    if (outstyle == LATEX)
+	      fputc('\\', outf);   /* see comment above */
 	    if (floorby == REQUESTS)
-	      c = lngstr[method2relpc[requests]];
+	      mprintf(outf, pagewidth, "%s", lngstr[method2relpc[requests]]);
 	    else if (floorby == REQUESTS7)
-	      c = lngstr[method2relpc[requests7]];
+	      mprintf(outf, pagewidth, "%s", lngstr[method2relpc[requests7]]);
 	    else
-	      c = lngstr[method2relpc[floorby]];
-	    if (outstyle == LATEX) { /* and again, change one % to \%. */
-	      ENSURE_LEN(t, tlen, strlen(c) + 2);
-	      strcpy(t, c);
-	      if ((c = strchr(t, '%')) != NULL) {
-		memmove(c + 1, c, strlen(c) + 1);
-		*c = '\\';
-	      }
-	      c = t;
-	    }
-	    mprintf(outf, pagewidth, "%s", c);
+	      mprintf(outf, pagewidth, "%s", lngstr[method2relpc[floorby]]);
 	  }
 	  else { /* if qual is anything else, must be (k|M|G|T)bytes */
 	    lngs = (floorby == BYTES)?lngstr[xbytestraffic_]:\
@@ -1439,7 +1427,7 @@ char printcols(FILE *outf, Outchoices *od, choice rep, unsigned long reqs,
      verbchar at the end for the cases in which calling functions need to
      terminate the \verb */
   char *verbchar = "|+/!^#-=?_\\~'$\"()<>[]{}.,&;";
-  char lastditch[] = {(char)(0xF7)};   /* the division sign in ISO-8859-[12] */
+  char lastditch[] = {(char)(0xBE)};   /* the character 3/4 in ISO-8859-1 */
   choice outstyle, saveoutstyle;
   int c, i;
 
@@ -2062,11 +2050,11 @@ void piechart_caption(FILE *outf, choice rep, choice chartby, char **lngstr) {
     fprintf(outf, "<p><em>%s</em>\n", caption);
 }
 
-int piechart_wedge(FILE *outf, Outchoices *od, double angle, char *s) {
-  /* The angle is expressed between 0 and 1. Returns col if wedge was big
-     enough to be coloured in, NO_COLOURS for grey, else -1. */
+void piechart_wedge(FILE *outf, Outchoices *od, double angle, char *s,
+		    char *extension) {
+  /* the angle is expressed between 0 and 1 */
   double x, y, newangle, medangle;
-  int colour = black, rc = -1;
+  int colour = black;
   char t[MAXCHARS];
   size_t len;
 
@@ -2075,7 +2063,7 @@ int piechart_wedge(FILE *outf, Outchoices *od, double angle, char *s) {
     colour = grey;
   }
   else if (col >= NO_COLOURS)
-    angle = 0;  /* As a signal not to make a wedge. Can this happen? */
+    angle = 0;  /* as a signal not to make a wedge */
   else if (angle >= MINANGLE)
     colour = colours[col];
 
@@ -2095,14 +2083,13 @@ int piechart_wedge(FILE *outf, Outchoices *od, double angle, char *s) {
       PIE_EPSILON;
     gdImageLine(im, XCENTRE, YCENTRE, (int)x, (int)y, black);
 
-    /* Fill wedge */
+    /* fill wedge */
     medangle = totangle + angle / 2.;
     x = (double)XCENTRE + (double)DIAMETER * cos(medangle * TWOPI) / 2.5;
     y = (double)YCENTRE + (double)DIAMETER * sin(medangle * TWOPI) / 2.5;
-    if (gdImageGetPixel(im, (int)x, (int)y) == white) {  /* room to colour */
+    if (gdImageGetPixel(im, (int)x, (int)y) == white) {
       gdImageFill(im, (int)x, (int)y, colour);
-      /* Make label for wedge. If !normalchart, this is done in piechart_key()
-	 below instead. (See long comment near bottom of piechart().) */
+      /* make label for wedge */
       if (normalchart) {
 	gdImageFilledRectangle(im, BOXESLEFT, boxesy, BOXESLEFT + BOXESSIZE,
 			       boxesy + BOXESSIZE, colour);
@@ -2122,24 +2109,19 @@ int piechart_wedge(FILE *outf, Outchoices *od, double angle, char *s) {
 		      (unsigned char *)t, black);
 	boxesy += TEXTGAP;
       }
-      rc = (colour == grey)?NO_COLOURS:col;
-    }   /* end if (room to colour) */
+      else {
+	fputs("<br><img src=\"", outf);
+	htmlfprintf(outf, od, FALSE, od->imagedir, FALSE);
+	if (colour == grey)
+	  fprintf(outf, "sqg%c%s", EXTSEP, extension);
+	else
+	  fprintf(outf, "sq%d%c%s", col, EXTSEP, extension);
+	fprintf(outf, "\" alt=\"\"> %s\n", s);
+      }
+    }
     totangle = newangle;
     col++;
   }
-  return(rc);
-}
-
-void piechart_key(FILE *outf, Outchoices *od, int col, char *s,
-		  char *extension) {
-  /* Only called if !normalchart and wedge was included on chart */
-  fputs("<br><img src=\"", outf);
-  htmlfprintf(outf, od, FALSE, od->imagedir, FALSE);
-  if (col == NO_COLOURS)
-    fprintf(outf, "sqg%c%s", EXTSEP, extension);
-  else
-    fprintf(outf, "sq%d%c%s", col, EXTSEP, extension);
-  fprintf(outf, "\" alt=\"\"> %s\n", s);
 }
 
 void piechart_write(FILE *pieoutf, char *filename, logical jpegcharts) {
@@ -2170,7 +2152,6 @@ void piechart(FILE *outf, Outchoices *od, choice rep, Hashindex *items,
 
   Wedge wedge[NO_COLOURS];
   FILE *pieoutf;
-  int key[NO_COLOURS], keyg;
   Hashindex *p;
   double angle, smallestangle, largestangle;
   int smallestwedge;
@@ -2278,30 +2259,26 @@ void piechart(FILE *outf, Outchoices *od, choice rep, Hashindex *items,
 	  extension);
   if ((pieoutf = piechart_init(filename)) == NULL)
     return;  /* Warning message is given in piechart_init() */
+  fprintf(outf, "<p><img src=\"%s%s%c%s\" alt=\"\">\n", od->chartdir,
+	  anchorname[rep], EXTSEP, extension);
 
   /* Now we can finally get round to plotting the chart */
+  piechart_caption(outf, rep, od->chartby[G(rep)], lngstr);
   for (i = 0; i < NO_COLOURS; i++) {
-    key[i] = -1;
     if (wedge[i].name != NULL) {
       /* ugly special cases to construct name lifted from maketreename() */
-      if (rep == REP_TYPE && !STREQ(wedge[i].name, LNGSTR_NOEXT) &&
-	  !STREQ(wedge[i].name, LNGSTR_BRKDIRS)) {
+      if (rep == REP_TYPE) {
 	strcpy(workspace, ".");
 	strcat(workspace, wedge[i].name);
       }
       else
 	strcpy(workspace, wedge[i].name);
-      if ((rep == REP_REFSITE || rep == REP_DIR) &&
-	  !STREQ(wedge[i].name, LNGSTR_NODIR) &&
-	  !STREQ(wedge[i].name, LNGSTR_ROOTDIR))
+      if (rep == REP_REFSITE || rep == REP_DIR)
 	strcat(workspace, "/");
       do_aliasx(workspace, od->aliashead[G(rep)]);
-      key[i] = piechart_wedge(outf, od, wedge[i].angle, workspace);
-      /* retain i -> colour mapping for calling piechart_key() below */
+      piechart_wedge(outf, od, wedge[i].angle, workspace, extension);
     }
   }
-  if (normalchart)
-    piechart_caption(outf, rep, od->chartby[G(rep)], lngstr);
 
   /* Plot the catch-all wedge and close the file */
   if (gender == 'm')
@@ -2310,34 +2287,7 @@ void piechart(FILE *outf, Outchoices *od, choice rep, Hashindex *items,
     otherstr = lngstr[otherf_];
   else
     otherstr = lngstr[othern_];
-  keyg = piechart_wedge(outf, od, -1., otherstr);
+  piechart_wedge(outf, od, -1., otherstr, extension);
   piechart_write(pieoutf, filename, od->jpegcharts);
-
-  /* Now the text on the page. In CGI mode, this must be done _after_ the image
-     is closed, or the browser may fail to find the image. This is why printing
-     the caption and key must be done twice; above here if normalchart, below
-     here otherwise. */
-  fprintf(outf, "<p><img src=\"%s%s%c%s\" alt=\"\">\n", od->chartdir,
-	  anchorname[rep], EXTSEP, extension);
-  if (!normalchart) {
-    piechart_caption(outf, rep, od->chartby[G(rep)], lngstr);
-    for (i = 0; i < NO_COLOURS; i++) {
-      if (key[i] != -1) {
-	/* repeat above ugly special cases */
-	if (rep == REP_TYPE) {
-	  strcpy(workspace, ".");
-	  strcat(workspace, wedge[i].name);
-	}
-	else
-	  strcpy(workspace, wedge[i].name);
-	if (rep == REP_REFSITE || rep == REP_DIR)
-	  strcat(workspace, "/");
-	do_aliasx(workspace, od->aliashead[G(rep)]);
-	piechart_key(outf, od, key[i], workspace, extension);
-      }
-    }
-    if (keyg != -1)
-      piechart_key(outf, od, keyg, otherstr, extension);
-  }
 }
 #endif  /* NOGRAPHICS */
