@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -79,9 +79,9 @@ void report_compile(void) {
   printf("  No pie charts\n");
 #else
 #ifdef HAVE_GD
-  printf("  Pie chart code included -- using your libgd\n");
+  printf("  Pie charts included -- using your libgd\n");
 #else
-  printf("  Pie chart code included\n");
+  printf("  Pie charts included\n");
 #endif  /* HAVE_GD */
 #endif  /* NOGRAPHICS */
 #ifdef NOPIPES
@@ -92,7 +92,7 @@ void report_compile(void) {
 #ifdef NODNS
   printf("  No DNS lookups\n");
 #else
-  printf("  DNS lookup code included\n");
+  printf("  DNS lookups included\n");
 #ifdef NOALARM
   printf("  No DNS timeouts\n");
 #else
@@ -546,7 +546,7 @@ void report_outopts(Outchoices *od) {
     else if (od->outstyle == PLAIN)
       printf("PLAIN\n");
     else if (od->outstyle == LATEX)
-      printf("LATEX (and PDFLATEX is %s)\n", (od->pdflatex)?"ON":"OFF");
+      printf("LATEX\n");
     else {  /* OUT_NONE is reported above */
       printf("COMPUTER\n");
       printf("The field separator is \"%s\"\n", od->compsep);
@@ -625,13 +625,11 @@ void report_sep(char c, char *type) {
 
 void report_daterep(Outchoices *od, choice j) {
   report_cols(od->cols[j]);
-  if (j < DATEREPORTS_NUMBER) {
-    printf("    Maximum number of rows: ");
-    if (od->rows[j] == 0)
-      printf("unlimited\n");
-    else
-      printf("%u\n", od->rows[j]);
-  }
+  printf("    Maximum number of rows: ");
+  if (od->rows[j] == 0)
+    printf("unlimited\n");
+  else
+    printf("%u\n", od->rows[j]);
   printf("    Graphing by ");
   if (od->graph[j] == 'R' || od->graph[j] == 'r')
     printf("requests\n");
@@ -639,16 +637,17 @@ void report_daterep(Outchoices *od, choice j) {
     printf("requests for pages\n");
   else
     printf("bytes\n");
-  if (j < DATEREPORTS_NUMBER)
-    printf("    Displaying %s dates at top\n",
-	   (od->back[j])?"latest":"earliest");
+  printf("    Displaying %s dates at top\n",
+	 (od->back[j])?"latest":"earliest");
 }
 
 void report_genrep(Outchoices *od, choice j) {
   report_cols(od->cols[j]);
   report_sortby(od->sortby[G(j)], FALSE);
   report_floor(&(od->floor[G(j)]), FALSE);
-  if (od->subsortby[G(j)] != UNSET) {  /* report is hierarchical */
+  if (j == REP_REQ || j == REP_REDIR || j == REP_FAIL || j == REP_REF ||
+      j == REP_REDIRREF || j == REP_FAILREF || j == REP_TYPE || j == REP_DIR ||
+      j == REP_DOM || j == REP_REFSITE || j == REP_BROWSUM) {
     report_sortby(od->subsortby[G(j)], TRUE);
     report_floor(&(od->subfloor[G(j)]), TRUE);
   }
