@@ -1,4 +1,4 @@
-/***             analog 5.1             http://www.analog.cx/             ***/
+/***             analog 5.02             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -224,7 +224,7 @@ Hashindex *sorttree(Outchoices *od, Hashtable *tree, choice rep, Floor *floor,
   unhash(tree, &gooditems, &baditems);
   if (notcorrupt != NULL) {    /* NB notcorrupt only used for doms */
     baditems = (Hashindex *)submalloc(space, sizeof(Hashindex));
-    baditems->name = LNGSTR_UNKDOMAIN;
+    baditems->name = "\v";
     baditems->own = newhashentry(DATA_NUMBER, FALSE);
     baditems->other = NULL;
     baditems->next = NULL;
@@ -350,15 +350,9 @@ char *maketreename(Strlist *pn, Hashindex *p, Strlist **newpn, Strlist *space,
     return(p->name);
 
   if (rep == REP_TYPE || rep == REP_DOM || rep == REP_ORG) {
-    glue = '.';
+    back = !(rep == REP_DOM && pn != NULL && STREQ(pn->name, "\f"));
     /* back = TRUE unless numerical subdomains */
-    if (rep == REP_DOM && pn != NULL && STREQ(pn->name, LNGSTR_UNRESOLVED))
-      back = FALSE;
-    else if (rep == REP_ORG && pn != NULL &&
-	     ISDIGIT(pn->name[strlen(pn->name) - 1]))
-      back = FALSE;
-    else
-      back = TRUE;
+    glue = '.';
   }
   else {
     back = FALSE;
@@ -391,8 +385,7 @@ char *maketreename(Strlist *pn, Hashindex *p, Strlist **newpn, Strlist *space,
   if (rep == REP_DOM && !back) /* i.e. numerical subdomain: special case */
     TO_NEXT(sp);
   t = name;
-  if (rep == REP_TYPE && delims && !STREQ(p->name, LNGSTR_NOEXT) &&
-      !STREQ(p->name, LNGSTR_BRKDIRS))
+  if (rep == REP_TYPE && delims)
     /* delimiter at start: replicate in piechart() in output2.c */
     *(t++) = glue;
   if (rep == REP_BROWSUM && sp != NULL) {
@@ -411,8 +404,7 @@ char *maketreename(Strlist *pn, Hashindex *p, Strlist **newpn, Strlist *space,
     if (sp->next != NULL)
       *(t++) = glue;
   }
-  if (delims && (rep == REP_REFSITE || rep == REP_DIR) &&
-      !STREQ(p->name, LNGSTR_NODIR) && !STREQ(p->name, LNGSTR_ROOTDIR))
+  if (delims && (rep == REP_REFSITE || rep == REP_DIR))
     /* delimiter at end: replicate in piechart() in output2.c */
     *(t++) = glue;
   *t = '\0';
@@ -462,8 +454,7 @@ void rnextname(char **name, char **nameend, char *whole, logical build) {
 }
 
 void inextname(char **name, char **nameend, char *whole, logical build) {
-  static char *s0 = LNGSTR_NODIR;
-  static char *s1 = LNGSTR_ROOTDIR;
+  static char *s = "/";
   logical first = FALSE;
 
   if (*name == NULL) {
@@ -472,7 +463,6 @@ void inextname(char **name, char **nameend, char *whole, logical build) {
   }
   else if (IS_EMPTY_STRING(*nameend) || IS_EMPTY_STRING((*nameend) + 1) ||
 	   **nameend == '?' || *((*nameend) + 1) == '?') {
-    /* including s0 and s1 */
     *name = NULL;
     return;
   }
@@ -487,23 +477,21 @@ void inextname(char **name, char **nameend, char *whole, logical build) {
       ;  /* run to last consecutive '/' */
   }
   if ((**nameend == '\0' || **nameend == '?') && !build) {
-    if (first) {
-      if (**name != '/')
-	*name = s0;
-      else
-	*name = s1;
-      *nameend = strchr(*name, '\0');
+    if (first && **name != '/') {
+      *name = s;
+      *nameend = s + 1;
     }
+    else if (first)
+      *name = *nameend;
     else
       *name = NULL;
   }
 }
 
-static logical isnum = FALSE;  /* used in onextname() and Znextname() */
-
 void onextname(char **name, char **nameend, char *whole, logical build) {
-  static char *s0 = LNGSTR_UNRESOLVED;
-  static char *s1 = LNGSTR_NODOMAIN;
+  static char *s0 = "\f";
+  static char *s1 = "\b";
+  static logical isnum = FALSE;
 
   if (*name == NULL) {
     isnum = FALSE;
@@ -511,13 +499,13 @@ void onextname(char **name, char **nameend, char *whole, logical build) {
     if (!build) {
       if (strchr(whole, '.') == NULL) {
 	*name = s1;
-	*nameend = strchr(*name, '\0');
+	*nameend = s1 + 1;
 	debug('V', "%s", whole);
 	return;
       }
       if (ISDIGIT(*(*nameend - 1))) {
 	*name = s0;
-	*nameend = strchr(*name, '\0');
+	*nameend = s0 + 1;
 	isnum = TRUE;
 	return;
       }
@@ -525,7 +513,7 @@ void onextname(char **name, char **nameend, char *whole, logical build) {
     else if (ISDIGIT(*whole) &&  /* test for num. more subtle while building */
 	     (ISDIGIT(*(*nameend - 1)) || *(*nameend - 1) == '*')) {
       *name = s0;
-      *nameend = strchr(*name, '\0');
+      *nameend = s0 + 1;
       isnum = TRUE;
       return;
     }
@@ -558,9 +546,6 @@ void onextname(char **name, char **nameend, char *whole, logical build) {
 }
 
 void tnextname(char **name, char **nameend, char *whole, logical build) {
-  static char *s0 = LNGSTR_NOEXT;
-  static char *s1 = LNGSTR_BRKDIRS;
-
   logical first = FALSE;
 
   if (*name == NULL) {
@@ -568,29 +553,24 @@ void tnextname(char **name, char **nameend, char *whole, logical build) {
       *nameend = strchr(whole, '\0');
     first = TRUE;
   }
-  else if (*name == s0 || *name == s1 || *name == whole ||
-	   *name == whole + 1 || **name == '/') {
+  else if (*name == whole || *name == whole + 1 || **name == '/') {
     *name = NULL;
     return;
   }
   else
     *nameend = *name - 1;
-
   *name = *nameend - 1;
-  if (**name == '/' && first) {
-    *name = s1;
-    *nameend = strchr(*name, '\0');
+  if (**name == '/' && first)
     return;
-  }
   for ( ; **name != '.' && **name != '/' && *name != whole; (*name)--)
     ;
-  if (**name == '.' && (*name) + 1 != *nameend)
+  if (**name == '.')
     (*name)++;
   else if (build)
     return;
   else if (first) {
-    *name = s0;
-    *nameend = strchr(*name, '\0');
+    *name = whole;
+    *nameend = whole;
   }
   else
     *name = NULL;
@@ -618,59 +598,27 @@ void snextname(char **name, char **nameend, char *whole, logical build) {
 }
 
 void Znextname(char **name, char **nameend, char *whole, logical build) {
-  static char *s1 = LNGSTR_NODOMAIN;
-  static char *s2 = LNGSTR_UNKDOMAIN;
+  static char *s0 = "\f";
+  static char *s1 = "\b";
+  static char *s2 = "\v";
   extern Strpair **domlevels;
 
   Strpair *ap;
   unsigned int c;
 
   if (*name == NULL) {
-    isnum = FALSE;
     *nameend = strchr(whole, '\0');
-    if (ISDIGIT(*(*nameend - 1)) ||
-	(build && ISDIGIT(*whole) && *(*nameend - 1) == '*')) { /* num. addr */
-      *name = whole;
-      for (c = 0, *nameend = *name;
-	   *nameend - *name <= 3 && ISDIGIT(**nameend); (*nameend)++) {
-	c *= 10;
-	c += **nameend - '0';
-      }   /* c is now first component of IP address */
-      if (**nameend != '.' || *nameend == *name || c > 255) {
-	/* coz of this check, Org Rep can get more s1's & s2's than Dom Rep */
-	if (strchr(*name, '.') == NULL)
-	  *name = s1;
-	else
-	  *name = s2;
-	*nameend = strchr(*name, '\0');
-	return;
-      }
-      if (c < 128)  /* change c to be number of components required */
-	c = 1;
-      else if (c < 192)
-	c = 2;
-      else
-	c = 3;
-      for ( ; c > 1; c--) {
-	(*nameend)++;
-	while (ISDIGIT(**nameend))
-	  (*nameend)++;
-	if (**nameend != '.' && !build) {
-	  *name = s2;
-	  *nameend = strchr(*name, '\0');
-	  return;
-	}
-      }
-      isnum = TRUE;
+    if (ISDIGIT(*(*nameend - 1))) {
+      *name = s0;
+      *nameend = s0 + 1;
       return;
     }
-    /* non-numerical addresses */
     for (*name = *nameend; **name != '.' && *name != whole; (*name)--)
       ;
     if (*name == whole) {
       if (!build) {
 	*name = s1;
-	*nameend = strchr(*name, '\0');
+	*nameend = s1 + 1;
       }
       return;
     }
@@ -685,7 +633,7 @@ void Znextname(char **name, char **nameend, char *whole, logical build) {
       ;
     if (ap == NULL) {  /* domain not found */
       *name = s2;
-      *nameend = strchr(*name, '\0');
+      *nameend = s2 + 1;
       return;
     }
     /* otherwise we've now found the right number of levels */
@@ -708,7 +656,6 @@ void Znextname(char **name, char **nameend, char *whole, logical build) {
 }
 
 void bnextname(char **name, char **nameend, char *whole, logical build) {
-  /* See Bnextname() below for annotation */
 
   if (*name == NULL) {
     *name = whole;
@@ -748,54 +695,45 @@ void pnextname(char **name, char **nameend, char *whole, logical build) {
     *name = NULL;
 }
 
-/* When compiling the Browser Summary, browser names go through three
-   functions. First Bnextname() locates the bit corresponding to the browser
-   name and version (this is most of the work). Then do_aliasb() makes slight
-   adjustments to get it into canonical form (Name/v.v). Then bnextname()
-   does the actual tree-ification of this canonical form.                    */
 void Bnextname(char **name, char **nameend, char *whole, void *arg) {
   /* NB "arg" is ignored */
-  static char *s1 = "Netscape (compatible)";
-  size_t len;
+  static char *s1 = "Mozilla (compatible)";
+  static char *s2 = "Mosaic";
+  char *temps;
 
   if (*name == NULL) {
-    /* First recognise some strings anywhere in the name (mostly claiming to be
-       "Mozilla (compatible)"). The order may matter, for example if some
-       browsers claim to both be Mozilla (compatible) and MSIE (compatible).
-       Note that "len =" is simple assignment and will always return true; it's
-       just a way of setting len. */
-    if (((*name = strstr(whole, "Mosaic")) != NULL && (len = 6)) ||
-	((*name = strstr(whole, "mosaic")) != NULL && (len = 6)) ||
-	((*name = strstr(whole, "Konqueror")) != NULL && (len = 9)) ||
-	((*name = strstr(whole, "Netscape6")) != NULL && (len = 9)) ||
-	((*name = strstr(whole, "Galeon")) != NULL && (len = 6)) ||
-	((*name = strstr(whole, "WebTV")) != NULL && (len = 5)) ||
-	((*name = strstr(whole, "Opera")) != NULL && (len = 5)) ||
-	((*name = strstr(whole, "MSIE")) != NULL && (len = 4))) {
-      *nameend = *name + len;
-      if (**nameend == '/' || **nameend == ' ') {
-	for ((*nameend)++; ISALNUM(**nameend) || **nameend == '.' ||
-	       **nameend == '-' || **nameend == '+'; (*nameend)++)
-	  ;  /* run to end of version number */
-      }
-      else if (headmatch(*name, "Galeon") /* Galeon uses "Galeon; v.vv" */ &&
-	       **nameend == ';' && *(*nameend + 1) == ' ' &&
-	       ISDIGIT(*(*nameend + 2))) {
-	for ((*nameend) += 2; ISALNUM(**nameend) || **nameend == '.' ||
-	       **nameend == '-' || **nameend == '+'; (*nameend)++)
-	  ;
-      }
+    if (strstr(whole, "osaic") != NULL) {
+      *name = s2;
+      *nameend = s2 + 6;
     }
     else if (headmatch(whole, "Mozilla")) {
-      if (strstr(whole + 9, "compatible") || strstr(whole + 9, "Compatible")) {
-	*name = s1;
-	*nameend = s1 + 21;
+      /* try & do something nearly sensible for all the Moz. (compatible)'s */
+      if ((temps = strstr(whole + 8, "WebTV")) != NULL ||
+	  (temps = strstr(whole + 8, "Opera")) != NULL) {
+	*name = temps;
+
+	if (*(temps + 5) == '\0')
+	  *nameend = temps + 5;
+	else for (*nameend = temps + 6; ISALNUM(**nameend) || **nameend == '.';
+		  (*nameend)++)
+	  ;
       }
-      else {  /* probably genuine Netscape/Mozilla */
+      else if ((temps = strstr(whole + 8, "MSIE")) != NULL) {
+	*name = temps;
+	if (*(temps + 4) == '\0')
+	  *nameend = temps + 4;
+	else for (*nameend = temps + 5; ISALNUM(**nameend) || **nameend == '.';
+		  (*nameend)++)
+	  ;
+      }
+      else if (strstr(whole + 9, "ompatible")) {
+	*name = s1;
+	*nameend = s1 + 20;
+      }
+      else {  /* probably genuine Mozilla */
 	*name = whole;
-	/* Mozilla has version number much later so keep the whole string */
-	if (*(*name + 8) == '5' ||
-	    (*nameend = strchr(whole + 7, ' ')) == NULL)
+	*nameend = strchr(whole + 7, ' ');
+	if (*nameend == NULL)
 	  *nameend = strchr(whole + 7, '\0');
       }
     }
@@ -813,8 +751,8 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
 
   if (*name == NULL) {
     if (arg != NULL && included(whole, FALSE, (Include *)arg)) {
-      *name = "Robots";
-      *nameend = strchr(*name, '\0');
+      *name = "\v";
+      *nameend = (*name) + 1;
       return;
     }
     if (headmatch(whole, "Mozilla"))
@@ -832,39 +770,18 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
 	  *name = "Windows:Windows 95";
       else if (*c == '9' && *(c + 1) == '8') {
 	if (strstr(c, "Win 9x 4.9"))
-	  *name = "Windows:Windows ME";
+	  *name = "Windows:Windows Me";
 	else
 	  *name = "Windows:Windows 98";
       }
       else if (*c == 'N' && *(c + 1) == 'T') {
-	/* advance to NT version number, which corresponds to advertised OS */
-	c += 2;
-	if (*c == ' ')
-	  c++;
-	if (*c == '5') {
-	  if (*(c + 1) == '.' && (*(c + 2) == '0'))
-	    *name = "Windows:Windows 2000";
-	  else if (*(c + 1) == '.' && (*(c + 2) == '1'))
-	    *name = "Windows:Windows XP";
-	  else
-	    *name = "Windows:Unknown Windows";
-	}
-	else if (*c >= '6' && *c <= '9')
-	  *name = "Windows:Unknown Windows";
+	if (*(c + 2) == ' ' && *(c + 3) == '5')
+	  *name = "Windows:Windows 2000";
 	else
 	  *name = "Windows:Windows NT";
       }
       else if (*c == 'C' && *(c + 1) == 'E')
 	*name = "Windows:Windows CE";
-      /* next three not MSIE, but some other vendor might use them */
-      else if (*c == 'X' && *(c + 1) == 'P')
-	*name = "Windows:Windows XP";
-      else if (*c == '2' && *(c + 1) == '0' && *(c + 2) == '0' &&
-	       *(c + 3) == '0')
-	*name = "Windows:Windows 2000";
-      else if (*c == 'M' && (*(c + 1) == 'E' || (*(c + 1) == 'e') ||
-			     headmatch(c + 1, "illennium")))
-	*name = "Windows:Windows ME";
       else if (*c == '3' && *(c + 1) == '.' && *(c + 2) == '1')
 	*name = "Windows:Windows 3.1";
       else if ((*c == '1' && *(c + 1) == '6') || strstr(c + 1, "16bit") ||
@@ -874,7 +791,7 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
 	       strstr(c + 1, "32-bit"))
 	*name = "Windows:Windows 32-bit";
       else
-	*name = "Windows:Unknown Windows";
+	*name = "Windows:unkwin";
     }
     else if ((c = strstr(whole, "Mac")) != NULL) {
       if (strstr(c + 3, "68"))
@@ -882,7 +799,7 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
       else if (strstr(c + 3, "PPC") || strstr(c + 3, "PowerPC"))
 	*name = "Macintosh:Macintosh PowerPC";
       else
-	*name = "Macintosh:Unknown Macintosh";
+	*name = "Macintosh:unkmac";
     }
     else if (strstr(whole, "Linux") != NULL || strstr(whole, "linux") != NULL)
       *name = "Unix:Linux";
@@ -902,7 +819,7 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
     else if (strstr(whole, "VMS") != NULL)
       *name = "OpenVMS";
     else if (strstr(whole, "X11") != NULL)
-      *name = "Unix:Other Unix";
+      *name = "Unix:unkux";
     else if (strstr(whole, "WebTV") != NULL)
       *name = "WebTV";
     else if (strstr(whole, "OS/2") != NULL)
@@ -916,7 +833,7 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
     else if (strstr(whole, "Atari") != NULL)
       *name = "Atari";
     else
-      *name = "OS unknown";
+      *name = "unkos";
     *nameend = strchr(*name, '\0');
   }
   else
